from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import Literal, cast






T = TypeVar("T", bound="AwsSecretsManagerConfigurationOutput")



@_attrs_define
class AwsSecretsManagerConfigurationOutput:
    """ 
        Attributes:
            type_ (Literal['aws_secrets_manager']):
            region (str):
            access_key_id (str):
            secret_access_key (str):
     """

    type_: Literal['aws_secrets_manager']
    region: str
    access_key_id: str
    secret_access_key: str





    def to_dict(self) -> dict[str, Any]:
        type_ = self.type_

        region = self.region

        access_key_id = self.access_key_id

        secret_access_key = self.secret_access_key


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "type": type_,
            "region": region,
            "accessKeyId": access_key_id,
            "secretAccessKey": secret_access_key,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        type_ = cast(Literal['aws_secrets_manager'] , d.pop("type"))
        if type_ != 'aws_secrets_manager':
            raise ValueError(f"type must match const 'aws_secrets_manager', got '{type_}'")

        region = d.pop("region")

        access_key_id = d.pop("accessKeyId")

        secret_access_key = d.pop("secretAccessKey")

        aws_secrets_manager_configuration_output = cls(
            type_=type_,
            region=region,
            access_key_id=access_key_id,
            secret_access_key=secret_access_key,
        )

        return aws_secrets_manager_configuration_output




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset






T = TypeVar("T", bound="TestSecretResponse")



@_attrs_define
class TestSecretResponse:
    """ 
        Attributes:
            success (bool):
            message (str):
            value (str | Unset):
     """

    success: bool
    message: str
    value: str | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        success = self.success

        message = self.message

        value = self.value


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "success": success,
            "message": message,
        })
        if value is not UNSET:
            field_dict["value"] = value

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        success = d.pop("success")

        message = d.pop("message")

        value = d.pop("value", UNSET)

        test_secret_response = cls(
            success=success,
            message=message,
            value=value,
        )

        return test_secret_response




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast






T = TypeVar("T", bound="ServerOAuthMetadataResource")



@_attrs_define
class ServerOAuthMetadataResource:
    """ 
        Attributes:
            id (str):  Default: ''.
            available_scopes (list[str]):
            metadata_url (str):  Default: ''.
     """

    available_scopes: list[str]
    id: str = ''
    metadata_url: str = ''





    def to_dict(self) -> dict[str, Any]:
        id = self.id

        available_scopes = self.available_scopes



        metadata_url = self.metadata_url


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "id": id,
            "availableScopes": available_scopes,
            "metadataUrl": metadata_url,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        id = d.pop("id")

        available_scopes = cast(list[str], d.pop("availableScopes"))


        metadata_url = d.pop("metadataUrl")

        server_o_auth_metadata_resource = cls(
            id=id,
            available_scopes=available_scopes,
            metadata_url=metadata_url,
        )

        return server_o_auth_metadata_resource




from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define

if TYPE_CHECKING:
    from ..models.get_sandbox_id_audit_logs_id_response_200_pagination import (
        GetSandboxIdAuditLogsIdResponse200Pagination,
    )
    from ..models.sandbox_audit_log import SandboxAuditLog


T = TypeVar("T", bound="GetSandboxIdAuditLogsIdResponse200")


@_attrs_define
class GetSandboxIdAuditLogsIdResponse200:
    """
    Attributes:
        pagination (GetSandboxIdAuditLogsIdResponse200Pagination):
        data (list[SandboxAuditLog]):
    """

    pagination: GetSandboxIdAuditLogsIdResponse200Pagination
    data: list[SandboxAuditLog]

    def to_dict(self) -> dict[str, Any]:
        pagination = self.pagination.to_dict()

        data = []
        for data_item_data in self.data:
            data_item = data_item_data.to_dict()
            data.append(data_item)

        field_dict: dict[str, Any] = {}

        field_dict.update(
            {
                "pagination": pagination,
                "data": data,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.get_sandbox_id_audit_logs_id_response_200_pagination import (
            GetSandboxIdAuditLogsIdResponse200Pagination,
        )
        from ..models.sandbox_audit_log import SandboxAuditLog

        d = dict(src_dict)
        pagination = GetSandboxIdAuditLogsIdResponse200Pagination.from_dict(d.pop("pagination"))

        data = []
        _data = d.pop("data")
        for data_item_data in _data:
            data_item = SandboxAuditLog.from_dict(data_item_data)

            data.append(data_item)

        get_sandbox_id_audit_logs_id_response_200 = cls(
            pagination=pagination,
            data=data,
        )

        return get_sandbox_id_audit_logs_id_response_200



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import Literal, cast






T = TypeVar("T", bound="GcpSecretManagerConfiguration")



@_attrs_define
class GcpSecretManagerConfiguration:
    """ 
        Attributes:
            type_ (Literal['gcp_secret_manager']):
            project_id (str):
            service_account_key (str):
     """

    type_: Literal['gcp_secret_manager']
    project_id: str
    service_account_key: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        type_ = self.type_

        project_id = self.project_id

        service_account_key = self.service_account_key


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "type": type_,
            "projectId": project_id,
            "serviceAccountKey": service_account_key,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        type_ = cast(Literal['gcp_secret_manager'] , d.pop("type"))
        if type_ != 'gcp_secret_manager':
            raise ValueError(f"type must match const 'gcp_secret_manager', got '{type_}'")

        project_id = d.pop("projectId")

        service_account_key = d.pop("serviceAccountKey")

        gcp_secret_manager_configuration = cls(
            type_=type_,
            project_id=project_id,
            service_account_key=service_account_key,
        )


        gcp_secret_manager_configuration.additional_properties = d
        return gcp_secret_manager_configuration

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast






T = TypeVar("T", bound="CreatePersonalAccessTokenRequest")



@_attrs_define
class CreatePersonalAccessTokenRequest:
    """ 
        Attributes:
            name (str):
            profile_id (None | str | Unset):
     """

    name: str
    profile_id: None | str | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        name = self.name

        profile_id: None | str | Unset
        if isinstance(self.profile_id, Unset):
            profile_id = UNSET
        else:
            profile_id = self.profile_id


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "name": name,
        })
        if profile_id is not UNSET:
            field_dict["profileId"] = profile_id

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        name = d.pop("name")

        def _parse_profile_id(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        profile_id = _parse_profile_id(d.pop("profileId", UNSET))


        create_personal_access_token_request = cls(
            name=name,
            profile_id=profile_id,
        )


        create_personal_access_token_request.additional_properties = d
        return create_personal_access_token_request

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset







T = TypeVar("T", bound="GetMcpServersResponse200ServersItemUsage")



@_attrs_define
class GetMcpServersResponse200ServersItemUsage:
    """ 
        Attributes:
            last_seven_days (float):
     """

    last_seven_days: float





    def to_dict(self) -> dict[str, Any]:
        last_seven_days = self.last_seven_days


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "lastSevenDays": last_seven_days,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        last_seven_days = d.pop("lastSevenDays")

        get_mcp_servers_response_200_servers_item_usage = cls(
            last_seven_days=last_seven_days,
        )

        return get_mcp_servers_response_200_servers_item_usage




from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define

if TYPE_CHECKING:
    from ..models.sandbox_audit_log_details import SandboxAuditLogDetails


T = TypeVar("T", bound="SandboxAuditLog")


@_attrs_define
class SandboxAuditLog:
    """
    Attributes:
        id (float):
        tenant_id (str):
        sandbox_id (str):
        event_name (str):
        details (SandboxAuditLogDetails):
        created_at (str):
    """

    id: float
    tenant_id: str
    sandbox_id: str
    event_name: str
    details: SandboxAuditLogDetails
    created_at: str

    def to_dict(self) -> dict[str, Any]:
        id = self.id

        tenant_id = self.tenant_id

        sandbox_id = self.sandbox_id

        event_name = self.event_name

        details = self.details.to_dict()

        created_at = self.created_at

        field_dict: dict[str, Any] = {}

        field_dict.update(
            {
                "id": id,
                "tenantId": tenant_id,
                "sandboxId": sandbox_id,
                "eventName": event_name,
                "details": details,
                "createdAt": created_at,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.sandbox_audit_log_details import SandboxAuditLogDetails

        d = dict(src_dict)
        id = d.pop("id")

        tenant_id = d.pop("tenantId")

        sandbox_id = d.pop("sandboxId")

        event_name = d.pop("eventName")

        details = SandboxAuditLogDetails.from_dict(d.pop("details"))

        created_at = d.pop("createdAt")

        sandbox_audit_log = cls(
            id=id,
            tenant_id=tenant_id,
            sandbox_id=sandbox_id,
            event_name=event_name,
            details=details,
            created_at=created_at,
        )

        return sandbox_audit_log



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast

if TYPE_CHECKING:
  from ..models.server_pod_status import ServerPodStatus





T = TypeVar("T", bound="ServerRunningStatusResponse")



@_attrs_define
class ServerRunningStatusResponse:
    """ 
        Attributes:
            is_deployed (bool):
            is_available (bool):
            is_stabilizing (bool):
            pods (list[ServerPodStatus]):
     """

    is_deployed: bool
    is_available: bool
    is_stabilizing: bool
    pods: list[ServerPodStatus]





    def to_dict(self) -> dict[str, Any]:
        from ..models.server_pod_status import ServerPodStatus
        is_deployed = self.is_deployed

        is_available = self.is_available

        is_stabilizing = self.is_stabilizing

        pods = []
        for pods_item_data in self.pods:
            pods_item = pods_item_data.to_dict()
            pods.append(pods_item)




        field_dict: dict[str, Any] = {}

        field_dict.update({
            "isDeployed": is_deployed,
            "isAvailable": is_available,
            "isStabilizing": is_stabilizing,
            "pods": pods,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.server_pod_status import ServerPodStatus
        d = dict(src_dict)
        is_deployed = d.pop("isDeployed")

        is_available = d.pop("isAvailable")

        is_stabilizing = d.pop("isStabilizing")

        pods = []
        _pods = d.pop("pods")
        for pods_item_data in (_pods):
            pods_item = ServerPodStatus.from_dict(pods_item_data)



            pods.append(pods_item)


        server_running_status_response = cls(
            is_deployed=is_deployed,
            is_available=is_available,
            is_stabilizing=is_stabilizing,
            pods=pods,
        )

        return server_running_status_response




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset







T = TypeVar("T", bound="SecretMappingResponse")



@_attrs_define
class SecretMappingResponse:
    """ 
        Attributes:
            name (str):
            secret_identifier (str):
            created_at (str):
            updated_at (str):
     """

    name: str
    secret_identifier: str
    created_at: str
    updated_at: str





    def to_dict(self) -> dict[str, Any]:
        name = self.name

        secret_identifier = self.secret_identifier

        created_at = self.created_at

        updated_at = self.updated_at


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "name": name,
            "secretIdentifier": secret_identifier,
            "createdAt": created_at,
            "updatedAt": updated_at,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        name = d.pop("name")

        secret_identifier = d.pop("secretIdentifier")

        created_at = d.pop("createdAt")

        updated_at = d.pop("updatedAt")

        secret_mapping_response = cls(
            name=name,
            secret_identifier=secret_identifier,
            created_at=created_at,
            updated_at=updated_at,
        )

        return secret_mapping_response




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast






T = TypeVar("T", bound="UpdateServerRequestOauthMetadataType0ResourceType0")



@_attrs_define
class UpdateServerRequestOauthMetadataType0ResourceType0:
    """ 
        Attributes:
            id (str | Unset):  Default: ''.
            available_scopes (list[str] | Unset):
            metadata_url (str | Unset):  Default: ''.
     """

    id: str | Unset = ''
    available_scopes: list[str] | Unset = UNSET
    metadata_url: str | Unset = ''
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        id = self.id

        available_scopes: list[str] | Unset = UNSET
        if not isinstance(self.available_scopes, Unset):
            available_scopes = self.available_scopes



        metadata_url = self.metadata_url


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if id is not UNSET:
            field_dict["id"] = id
        if available_scopes is not UNSET:
            field_dict["availableScopes"] = available_scopes
        if metadata_url is not UNSET:
            field_dict["metadataUrl"] = metadata_url

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        id = d.pop("id", UNSET)

        available_scopes = cast(list[str], d.pop("availableScopes", UNSET))


        metadata_url = d.pop("metadataUrl", UNSET)

        update_server_request_oauth_metadata_type_0_resource_type_0 = cls(
            id=id,
            available_scopes=available_scopes,
            metadata_url=metadata_url,
        )


        update_server_request_oauth_metadata_type_0_resource_type_0.additional_properties = d
        return update_server_request_oauth_metadata_type_0_resource_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="ExecCommandBody")


@_attrs_define
class ExecCommandBody:
    """
    Attributes:
        command (str):
        workdir (None | str | Unset):
        timeout (float | None | Unset):
    """

    command: str
    workdir: None | str | Unset = UNSET
    timeout: float | None | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        command = self.command

        workdir: None | str | Unset
        if isinstance(self.workdir, Unset):
            workdir = UNSET
        else:
            workdir = self.workdir

        timeout: float | None | Unset
        if isinstance(self.timeout, Unset):
            timeout = UNSET
        else:
            timeout = self.timeout

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "command": command,
            }
        )
        if workdir is not UNSET:
            field_dict["workdir"] = workdir
        if timeout is not UNSET:
            field_dict["timeout"] = timeout

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        command = d.pop("command")

        def _parse_workdir(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        workdir = _parse_workdir(d.pop("workdir", UNSET))

        def _parse_timeout(data: object) -> float | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(float | None | Unset, data)

        timeout = _parse_timeout(d.pop("timeout", UNSET))

        exec_command_body = cls(
            command=command,
            workdir=workdir,
            timeout=timeout,
        )

        exec_command_body.additional_properties = d
        return exec_command_body

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class PutMcpServersServerSlugMembersMemberTypeMemberIdBodyRole(str, Enum):
    ADMIN = "admin"
    MAINTAINER = "maintainer"
    MEMBER = "member"

    def __str__(self) -> str:
        return str(self.value)



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast

if TYPE_CHECKING:
  from ..models.get_mcp_servers_response_200_servers_item import GetMcpServersResponse200ServersItem





T = TypeVar("T", bound="GetMcpServersResponse200")



@_attrs_define
class GetMcpServersResponse200:
    """ 
        Attributes:
            servers (list[GetMcpServersResponse200ServersItem]):
     """

    servers: list[GetMcpServersResponse200ServersItem]





    def to_dict(self) -> dict[str, Any]:
        from ..models.get_mcp_servers_response_200_servers_item import GetMcpServersResponse200ServersItem
        servers = []
        for servers_item_data in self.servers:
            servers_item = servers_item_data.to_dict()
            servers.append(servers_item)




        field_dict: dict[str, Any] = {}

        field_dict.update({
            "servers": servers,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.get_mcp_servers_response_200_servers_item import GetMcpServersResponse200ServersItem
        d = dict(src_dict)
        servers = []
        _servers = d.pop("servers")
        for servers_item_data in (_servers):
            servers_item = GetMcpServersResponse200ServersItem.from_dict(servers_item_data)



            servers.append(servers_item)


        get_mcp_servers_response_200 = cls(
            servers=servers,
        )

        return get_mcp_servers_response_200




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast






T = TypeVar("T", bound="PutProfilesProfileIdBody")



@_attrs_define
class PutProfilesProfileIdBody:
    """ 
        Attributes:
            name (str | Unset):
            description (str | Unset):
            is_open_to_all_users (bool | Unset):
            is_restrictive (bool | Unset):
            server_ids (list[str] | Unset):
     """

    name: str | Unset = UNSET
    description: str | Unset = UNSET
    is_open_to_all_users: bool | Unset = UNSET
    is_restrictive: bool | Unset = UNSET
    server_ids: list[str] | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        name = self.name

        description = self.description

        is_open_to_all_users = self.is_open_to_all_users

        is_restrictive = self.is_restrictive

        server_ids: list[str] | Unset = UNSET
        if not isinstance(self.server_ids, Unset):
            server_ids = self.server_ids




        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if name is not UNSET:
            field_dict["name"] = name
        if description is not UNSET:
            field_dict["description"] = description
        if is_open_to_all_users is not UNSET:
            field_dict["isOpenToAllUsers"] = is_open_to_all_users
        if is_restrictive is not UNSET:
            field_dict["isRestrictive"] = is_restrictive
        if server_ids is not UNSET:
            field_dict["serverIds"] = server_ids

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        name = d.pop("name", UNSET)

        description = d.pop("description", UNSET)

        is_open_to_all_users = d.pop("isOpenToAllUsers", UNSET)

        is_restrictive = d.pop("isRestrictive", UNSET)

        server_ids = cast(list[str], d.pop("serverIds", UNSET))


        put_profiles_profile_id_body = cls(
            name=name,
            description=description,
            is_open_to_all_users=is_open_to_all_users,
            is_restrictive=is_restrictive,
            server_ids=server_ids,
        )


        put_profiles_profile_id_body.additional_properties = d
        return put_profiles_profile_id_body

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, cast

from attrs import define as _attrs_define

if TYPE_CHECKING:
    from ..models.auth_metadata_quota import AuthMetadataQuota
    from ..models.auth_metadata_tenant import AuthMetadataTenant
    from ..models.auth_metadata_user import AuthMetadataUser


T = TypeVar("T", bound="AuthMetadata")


@_attrs_define
class AuthMetadata:
    """
    Attributes:
        is_playground (bool):
        has_paid_subscription (bool):
        user (AuthMetadataUser):
        tenant (AuthMetadataTenant):
        rules (list[Any]):
        quota (AuthMetadataQuota):
    """

    is_playground: bool
    has_paid_subscription: bool
    user: AuthMetadataUser
    tenant: AuthMetadataTenant
    rules: list[Any]
    quota: AuthMetadataQuota

    def to_dict(self) -> dict[str, Any]:
        is_playground = self.is_playground

        has_paid_subscription = self.has_paid_subscription

        user = self.user.to_dict()

        tenant = self.tenant.to_dict()

        rules = self.rules

        quota = self.quota.to_dict()

        field_dict: dict[str, Any] = {}

        field_dict.update(
            {
                "isPlayground": is_playground,
                "hasPaidSubscription": has_paid_subscription,
                "user": user,
                "tenant": tenant,
                "rules": rules,
                "quota": quota,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.auth_metadata_quota import AuthMetadataQuota
        from ..models.auth_metadata_tenant import AuthMetadataTenant
        from ..models.auth_metadata_user import AuthMetadataUser

        d = dict(src_dict)
        is_playground = d.pop("isPlayground")

        has_paid_subscription = d.pop("hasPaidSubscription")

        user = AuthMetadataUser.from_dict(d.pop("user"))

        tenant = AuthMetadataTenant.from_dict(d.pop("tenant"))

        rules = cast(list[Any], d.pop("rules"))

        quota = AuthMetadataQuota.from_dict(d.pop("quota"))

        auth_metadata = cls(
            is_playground=is_playground,
            has_paid_subscription=has_paid_subscription,
            user=user,
            tenant=tenant,
            rules=rules,
            quota=quota,
        )

        return auth_metadata



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast

if TYPE_CHECKING:
  from ..models.get_subscription_response_subscription_type_0 import GetSubscriptionResponseSubscriptionType0





T = TypeVar("T", bound="GetSubscriptionResponse")



@_attrs_define
class GetSubscriptionResponse:
    """ 
        Attributes:
            subscription_plan (str):
            subscription_seats (float):
            subscription (GetSubscriptionResponseSubscriptionType0 | None):
     """

    subscription_plan: str
    subscription_seats: float
    subscription: GetSubscriptionResponseSubscriptionType0 | None





    def to_dict(self) -> dict[str, Any]:
        from ..models.get_subscription_response_subscription_type_0 import GetSubscriptionResponseSubscriptionType0
        subscription_plan = self.subscription_plan

        subscription_seats = self.subscription_seats

        subscription: dict[str, Any] | None
        if isinstance(self.subscription, GetSubscriptionResponseSubscriptionType0):
            subscription = self.subscription.to_dict()
        else:
            subscription = self.subscription


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "subscriptionPlan": subscription_plan,
            "subscriptionSeats": subscription_seats,
            "subscription": subscription,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.get_subscription_response_subscription_type_0 import GetSubscriptionResponseSubscriptionType0
        d = dict(src_dict)
        subscription_plan = d.pop("subscriptionPlan")

        subscription_seats = d.pop("subscriptionSeats")

        def _parse_subscription(data: object) -> GetSubscriptionResponseSubscriptionType0 | None:
            if data is None:
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                subscription_type_0 = GetSubscriptionResponseSubscriptionType0.from_dict(data)



                return subscription_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(GetSubscriptionResponseSubscriptionType0 | None, data)

        subscription = _parse_subscription(d.pop("subscription"))


        get_subscription_response = cls(
            subscription_plan=subscription_plan,
            subscription_seats=subscription_seats,
            subscription=subscription,
        )

        return get_subscription_response




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, cast

from attrs import define as _attrs_define

from ..models.schema_67 import Schema67
from ..models.server_credentials_dto_type import ServerCredentialsDtoType

T = TypeVar("T", bound="ServerCredentialsDto")


@_attrs_define
class ServerCredentialsDto:
    """
    Attributes:
        id (str):
        tenant_id (str):
        scope (Schema67):
        user_id (float | None):
        profile_id (None | str):
        last_used_at (None | str):
        authorized_at (str):
        type_ (ServerCredentialsDtoType):
        created_at (str):
        updated_at (str):
        user_sub (None | str):
        user_email (None | str):
        user_name (None | str):
        profile_name (None | str):
        apikeys_present (list[str] | None):
        has_access_token (bool | None):
        access_token_expiry (None | str):
        has_refresh_token (bool | None):
        subject (None | str):
        email (None | str):
    """

    id: str
    tenant_id: str
    scope: Schema67
    user_id: float | None
    profile_id: None | str
    last_used_at: None | str
    authorized_at: str
    type_: ServerCredentialsDtoType
    created_at: str
    updated_at: str
    user_sub: None | str
    user_email: None | str
    user_name: None | str
    profile_name: None | str
    apikeys_present: list[str] | None
    has_access_token: bool | None
    access_token_expiry: None | str
    has_refresh_token: bool | None
    subject: None | str
    email: None | str

    def to_dict(self) -> dict[str, Any]:
        id = self.id

        tenant_id = self.tenant_id

        scope = self.scope.value

        user_id: float | None
        user_id = self.user_id

        profile_id: None | str
        profile_id = self.profile_id

        last_used_at: None | str
        last_used_at = self.last_used_at

        authorized_at = self.authorized_at

        type_ = self.type_.value

        created_at = self.created_at

        updated_at = self.updated_at

        user_sub: None | str
        user_sub = self.user_sub

        user_email: None | str
        user_email = self.user_email

        user_name: None | str
        user_name = self.user_name

        profile_name: None | str
        profile_name = self.profile_name

        apikeys_present: list[str] | None
        if isinstance(self.apikeys_present, list):
            apikeys_present = self.apikeys_present

        else:
            apikeys_present = self.apikeys_present

        has_access_token: bool | None
        has_access_token = self.has_access_token

        access_token_expiry: None | str
        access_token_expiry = self.access_token_expiry

        has_refresh_token: bool | None
        has_refresh_token = self.has_refresh_token

        subject: None | str
        subject = self.subject

        email: None | str
        email = self.email

        field_dict: dict[str, Any] = {}

        field_dict.update(
            {
                "id": id,
                "tenantId": tenant_id,
                "scope": scope,
                "userId": user_id,
                "profileId": profile_id,
                "lastUsedAt": last_used_at,
                "authorizedAt": authorized_at,
                "type": type_,
                "createdAt": created_at,
                "updatedAt": updated_at,
                "userSub": user_sub,
                "userEmail": user_email,
                "userName": user_name,
                "profileName": profile_name,
                "apikeysPresent": apikeys_present,
                "hasAccessToken": has_access_token,
                "accessTokenExpiry": access_token_expiry,
                "hasRefreshToken": has_refresh_token,
                "subject": subject,
                "email": email,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        id = d.pop("id")

        tenant_id = d.pop("tenantId")

        scope = Schema67(d.pop("scope"))

        def _parse_user_id(data: object) -> float | None:
            if data is None:
                return data
            return cast(float | None, data)

        user_id = _parse_user_id(d.pop("userId"))

        def _parse_profile_id(data: object) -> None | str:
            if data is None:
                return data
            return cast(None | str, data)

        profile_id = _parse_profile_id(d.pop("profileId"))

        def _parse_last_used_at(data: object) -> None | str:
            if data is None:
                return data
            return cast(None | str, data)

        last_used_at = _parse_last_used_at(d.pop("lastUsedAt"))

        authorized_at = d.pop("authorizedAt")

        type_ = ServerCredentialsDtoType(d.pop("type"))

        created_at = d.pop("createdAt")

        updated_at = d.pop("updatedAt")

        def _parse_user_sub(data: object) -> None | str:
            if data is None:
                return data
            return cast(None | str, data)

        user_sub = _parse_user_sub(d.pop("userSub"))

        def _parse_user_email(data: object) -> None | str:
            if data is None:
                return data
            return cast(None | str, data)

        user_email = _parse_user_email(d.pop("userEmail"))

        def _parse_user_name(data: object) -> None | str:
            if data is None:
                return data
            return cast(None | str, data)

        user_name = _parse_user_name(d.pop("userName"))

        def _parse_profile_name(data: object) -> None | str:
            if data is None:
                return data
            return cast(None | str, data)

        profile_name = _parse_profile_name(d.pop("profileName"))

        def _parse_apikeys_present(data: object) -> list[str] | None:
            if data is None:
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                apikeys_present_type_0 = cast(list[str], data)

                return apikeys_present_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(list[str] | None, data)

        apikeys_present = _parse_apikeys_present(d.pop("apikeysPresent"))

        def _parse_has_access_token(data: object) -> bool | None:
            if data is None:
                return data
            return cast(bool | None, data)

        has_access_token = _parse_has_access_token(d.pop("hasAccessToken"))

        def _parse_access_token_expiry(data: object) -> None | str:
            if data is None:
                return data
            return cast(None | str, data)

        access_token_expiry = _parse_access_token_expiry(d.pop("accessTokenExpiry"))

        def _parse_has_refresh_token(data: object) -> bool | None:
            if data is None:
                return data
            return cast(bool | None, data)

        has_refresh_token = _parse_has_refresh_token(d.pop("hasRefreshToken"))

        def _parse_subject(data: object) -> None | str:
            if data is None:
                return data
            return cast(None | str, data)

        subject = _parse_subject(d.pop("subject"))

        def _parse_email(data: object) -> None | str:
            if data is None:
                return data
            return cast(None | str, data)

        email = _parse_email(d.pop("email"))

        server_credentials_dto = cls(
            id=id,
            tenant_id=tenant_id,
            scope=scope,
            user_id=user_id,
            profile_id=profile_id,
            last_used_at=last_used_at,
            authorized_at=authorized_at,
            type_=type_,
            created_at=created_at,
            updated_at=updated_at,
            user_sub=user_sub,
            user_email=user_email,
            user_name=user_name,
            profile_name=profile_name,
            apikeys_present=apikeys_present,
            has_access_token=has_access_token,
            access_token_expiry=access_token_expiry,
            has_refresh_token=has_refresh_token,
            subject=subject,
            email=email,
        )

        return server_credentials_dto



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.update_server_request_oauth_client_configuration_type_0_grant_type import UpdateServerRequestOauthClientConfigurationType0GrantType
from ..types import UNSET, Unset
from typing import cast
from typing import Literal, cast






T = TypeVar("T", bound="UpdateServerRequestOauthClientConfigurationType0")



@_attrs_define
class UpdateServerRequestOauthClientConfigurationType0:
    """ 
        Attributes:
            client_id (str | Unset):  Default: ''.
            client_secret (str | Unset):  Default: ''.
            grant_type (UpdateServerRequestOauthClientConfigurationType0GrantType | Unset):
            client_auth_method (Literal['client_secret_basic'] | Literal['client_secret_post'] | Literal['none'] | str |
                Unset):
            scopes (str | Unset):  Default: ''.
     """

    client_id: str | Unset = ''
    client_secret: str | Unset = ''
    grant_type: UpdateServerRequestOauthClientConfigurationType0GrantType | Unset = UNSET
    client_auth_method: Literal['client_secret_basic'] | Literal['client_secret_post'] | Literal['none'] | str | Unset = UNSET
    scopes: str | Unset = ''
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        client_id = self.client_id

        client_secret = self.client_secret

        grant_type: str | Unset = UNSET
        if not isinstance(self.grant_type, Unset):
            grant_type = self.grant_type.value


        client_auth_method: Literal['client_secret_basic'] | Literal['client_secret_post'] | Literal['none'] | str | Unset
        if isinstance(self.client_auth_method, Unset):
            client_auth_method = UNSET
        else:
            client_auth_method = self.client_auth_method

        scopes = self.scopes


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if client_id is not UNSET:
            field_dict["clientId"] = client_id
        if client_secret is not UNSET:
            field_dict["clientSecret"] = client_secret
        if grant_type is not UNSET:
            field_dict["grantType"] = grant_type
        if client_auth_method is not UNSET:
            field_dict["clientAuthMethod"] = client_auth_method
        if scopes is not UNSET:
            field_dict["scopes"] = scopes

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        client_id = d.pop("clientId", UNSET)

        client_secret = d.pop("clientSecret", UNSET)

        _grant_type = d.pop("grantType", UNSET)
        grant_type: UpdateServerRequestOauthClientConfigurationType0GrantType | Unset
        if isinstance(_grant_type,  Unset):
            grant_type = UNSET
        else:
            grant_type = UpdateServerRequestOauthClientConfigurationType0GrantType(_grant_type)




        def _parse_client_auth_method(data: object) -> Literal['client_secret_basic'] | Literal['client_secret_post'] | Literal['none'] | str | Unset:
            if isinstance(data, Unset):
                return data
            client_auth_method_type_0 = cast(Literal['client_secret_basic'] , data)
            if client_auth_method_type_0 != 'client_secret_basic':
                raise ValueError(f"clientAuthMethod_type_0 must match const 'client_secret_basic', got '{client_auth_method_type_0}'")
            return client_auth_method_type_0
            client_auth_method_type_1 = cast(Literal['client_secret_post'] , data)
            if client_auth_method_type_1 != 'client_secret_post':
                raise ValueError(f"clientAuthMethod_type_1 must match const 'client_secret_post', got '{client_auth_method_type_1}'")
            return client_auth_method_type_1
            client_auth_method_type_2 = cast(Literal['none'] , data)
            if client_auth_method_type_2 != 'none':
                raise ValueError(f"clientAuthMethod_type_2 must match const 'none', got '{client_auth_method_type_2}'")
            return client_auth_method_type_2
            return cast(Literal['client_secret_basic'] | Literal['client_secret_post'] | Literal['none'] | str | Unset, data)

        client_auth_method = _parse_client_auth_method(d.pop("clientAuthMethod", UNSET))


        scopes = d.pop("scopes", UNSET)

        update_server_request_oauth_client_configuration_type_0 = cls(
            client_id=client_id,
            client_secret=client_secret,
            grant_type=grant_type,
            client_auth_method=client_auth_method,
            scopes=scopes,
        )


        update_server_request_oauth_client_configuration_type_0.additional_properties = d
        return update_server_request_oauth_client_configuration_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define

T = TypeVar("T", bound="Schema65")


@_attrs_define
class Schema65:
    """
    Attributes:
        success (bool):
        message (str):
    """

    success: bool
    message: str

    def to_dict(self) -> dict[str, Any]:
        success = self.success

        message = self.message

        field_dict: dict[str, Any] = {}

        field_dict.update(
            {
                "success": success,
                "message": message,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        success = d.pop("success")

        message = d.pop("message")

        schema_65 = cls(
            success=success,
            message=message,
        )

        return schema_65



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset







T = TypeVar("T", bound="Profile")



@_attrs_define
class Profile:
    """ 
        Attributes:
            tenant_id (str):
            id (str):
            created_by (float):
            name (str):
            description (str):
            is_open_to_all_users (bool):
            is_restrictive (bool):
            created_at (str):
            updated_at (str):
     """

    tenant_id: str
    id: str
    created_by: float
    name: str
    description: str
    is_open_to_all_users: bool
    is_restrictive: bool
    created_at: str
    updated_at: str





    def to_dict(self) -> dict[str, Any]:
        tenant_id = self.tenant_id

        id = self.id

        created_by = self.created_by

        name = self.name

        description = self.description

        is_open_to_all_users = self.is_open_to_all_users

        is_restrictive = self.is_restrictive

        created_at = self.created_at

        updated_at = self.updated_at


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "tenantId": tenant_id,
            "id": id,
            "createdBy": created_by,
            "name": name,
            "description": description,
            "isOpenToAllUsers": is_open_to_all_users,
            "isRestrictive": is_restrictive,
            "createdAt": created_at,
            "updatedAt": updated_at,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        tenant_id = d.pop("tenantId")

        id = d.pop("id")

        created_by = d.pop("createdBy")

        name = d.pop("name")

        description = d.pop("description")

        is_open_to_all_users = d.pop("isOpenToAllUsers")

        is_restrictive = d.pop("isRestrictive")

        created_at = d.pop("createdAt")

        updated_at = d.pop("updatedAt")

        profile = cls(
            tenant_id=tenant_id,
            id=id,
            created_by=created_by,
            name=name,
            description=description,
            is_open_to_all_users=is_open_to_all_users,
            is_restrictive=is_restrictive,
            created_at=created_at,
            updated_at=updated_at,
        )

        return profile




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast

if TYPE_CHECKING:
  from ..models.secret_store_response import SecretStoreResponse





T = TypeVar("T", bound="SecretStoreListResponse")



@_attrs_define
class SecretStoreListResponse:
    """ 
        Attributes:
            stores (list[SecretStoreResponse]):
     """

    stores: list[SecretStoreResponse]





    def to_dict(self) -> dict[str, Any]:
        from ..models.secret_store_response import SecretStoreResponse
        stores = []
        for stores_item_data in self.stores:
            stores_item = stores_item_data.to_dict()
            stores.append(stores_item)




        field_dict: dict[str, Any] = {}

        field_dict.update({
            "stores": stores,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.secret_store_response import SecretStoreResponse
        d = dict(src_dict)
        stores = []
        _stores = d.pop("stores")
        for stores_item_data in (_stores):
            stores_item = SecretStoreResponse.from_dict(stores_item_data)



            stores.append(stores_item)


        secret_store_list_response = cls(
            stores=stores,
        )

        return secret_store_list_response




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset







T = TypeVar("T", bound="TeamClaimMapping")



@_attrs_define
class TeamClaimMapping:
    """ 
        Attributes:
            id (str):
            tenant_id (str):
            team_id (str):
            claim_key (str):
            claim_value (str):
            created_at (str):
     """

    id: str
    tenant_id: str
    team_id: str
    claim_key: str
    claim_value: str
    created_at: str





    def to_dict(self) -> dict[str, Any]:
        id = self.id

        tenant_id = self.tenant_id

        team_id = self.team_id

        claim_key = self.claim_key

        claim_value = self.claim_value

        created_at = self.created_at


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "id": id,
            "tenantId": tenant_id,
            "teamId": team_id,
            "claimKey": claim_key,
            "claimValue": claim_value,
            "createdAt": created_at,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        id = d.pop("id")

        tenant_id = d.pop("tenantId")

        team_id = d.pop("teamId")

        claim_key = d.pop("claimKey")

        claim_value = d.pop("claimValue")

        created_at = d.pop("createdAt")

        team_claim_mapping = cls(
            id=id,
            tenant_id=tenant_id,
            team_id=team_id,
            claim_key=claim_key,
            claim_value=claim_value,
            created_at=created_at,
        )

        return team_claim_mapping




from http import HTTPStatus
from typing import Any, cast
from urllib.parse import quote

import httpx

from ...client import AuthenticatedClient, Client
from ...types import Response, UNSET
from ... import errors

from ...models.put_profiles_profile_id_servers_server_slug_tools_body import PutProfilesProfileIdServersServerSlugToolsBody
from ...models.put_profiles_profile_id_servers_server_slug_tools_response_200 import PutProfilesProfileIdServersServerSlugToolsResponse200
from ...types import UNSET, Unset
from typing import cast



def _get_kwargs(
    profile_id: str,
    server_slug: str,
    *,
    body: PutProfilesProfileIdServersServerSlugToolsBody | Unset = UNSET,

) -> dict[str, Any]:
    headers: dict[str, Any] = {}


    

    

    _kwargs: dict[str, Any] = {
        "method": "put",
        "url": "/profiles/{profile_id}/servers/{server_slug}/tools".format(profile_id=quote(str(profile_id), safe=""),server_slug=quote(str(server_slug), safe=""),),
    }

    
    if not isinstance(body, Unset):
        _kwargs["json"] = body.to_dict()


    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs



def _parse_response(*, client: AuthenticatedClient | Client, response: httpx.Response) -> PutProfilesProfileIdServersServerSlugToolsResponse200 | None:
    if response.status_code == 200:
        response_200 = PutProfilesProfileIdServersServerSlugToolsResponse200.from_dict(response.json())



        return response_200

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: AuthenticatedClient | Client, response: httpx.Response) -> Response[PutProfilesProfileIdServersServerSlugToolsResponse200]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    profile_id: str,
    server_slug: str,
    *,
    client: AuthenticatedClient | Client,
    body: PutProfilesProfileIdServersServerSlugToolsBody | Unset = UNSET,

) -> Response[PutProfilesProfileIdServersServerSlugToolsResponse200]:
    """ 
    Args:
        profile_id (str):
        server_slug (str):
        body (PutProfilesProfileIdServersServerSlugToolsBody | Unset):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[PutProfilesProfileIdServersServerSlugToolsResponse200]
     """


    kwargs = _get_kwargs(
        profile_id=profile_id,
server_slug=server_slug,
body=body,

    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)

def sync(
    profile_id: str,
    server_slug: str,
    *,
    client: AuthenticatedClient | Client,
    body: PutProfilesProfileIdServersServerSlugToolsBody | Unset = UNSET,

) -> PutProfilesProfileIdServersServerSlugToolsResponse200 | None:
    """ 
    Args:
        profile_id (str):
        server_slug (str):
        body (PutProfilesProfileIdServersServerSlugToolsBody | Unset):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        PutProfilesProfileIdServersServerSlugToolsResponse200
     """


    return sync_detailed(
        profile_id=profile_id,
server_slug=server_slug,
client=client,
body=body,

    ).parsed

async def asyncio_detailed(
    profile_id: str,
    server_slug: str,
    *,
    client: AuthenticatedClient | Client,
    body: PutProfilesProfileIdServersServerSlugToolsBody | Unset = UNSET,

) -> Response[PutProfilesProfileIdServersServerSlugToolsResponse200]:
    """ 
    Args:
        profile_id (str):
        server_slug (str):
        body (PutProfilesProfileIdServersServerSlugToolsBody | Unset):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[PutProfilesProfileIdServersServerSlugToolsResponse200]
     """


    kwargs = _get_kwargs(
        profile_id=profile_id,
server_slug=server_slug,
body=body,

    )

    response = await client.get_async_httpx_client().request(
        **kwargs
    )

    return _build_response(client=client, response=response)

async def asyncio(
    profile_id: str,
    server_slug: str,
    *,
    client: AuthenticatedClient | Client,
    body: PutProfilesProfileIdServersServerSlugToolsBody | Unset = UNSET,

) -> PutProfilesProfileIdServersServerSlugToolsResponse200 | None:
    """ 
    Args:
        profile_id (str):
        server_slug (str):
        body (PutProfilesProfileIdServersServerSlugToolsBody | Unset):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        PutProfilesProfileIdServersServerSlugToolsResponse200
     """


    return (await asyncio_detailed(
        profile_id=profile_id,
server_slug=server_slug,
client=client,
body=body,

    )).parsed



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import Literal, cast






T = TypeVar("T", bound="PutMcpServersServerSlugConfigBodyType4")



@_attrs_define
class PutMcpServersServerSlugConfigBodyType4:
    """ 
        Attributes:
            type_ (Literal['self'] | Unset):
            id (str | Unset):
     """

    type_: Literal['self'] | Unset = UNSET
    id: str | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        type_ = self.type_

        id = self.id


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if type_ is not UNSET:
            field_dict["type"] = type_
        if id is not UNSET:
            field_dict["id"] = id

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        type_ = cast(Literal['self'] | Unset , d.pop("type", UNSET))
        if type_ != 'self'and not isinstance(type_, Unset):
            raise ValueError(f"type must match const 'self', got '{type_}'")

        id = d.pop("id", UNSET)

        put_mcp_servers_server_slug_config_body_type_4 = cls(
            type_=type_,
            id=id,
        )


        put_mcp_servers_server_slug_config_body_type_4.additional_properties = d
        return put_mcp_servers_server_slug_config_body_type_4

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define

from ..models.schema_40 import Schema40
from ..types import UNSET, Unset

T = TypeVar("T", bound="AuthMetadataUser")


@_attrs_define
class AuthMetadataUser:
    """
    Attributes:
        id (float):
        sub (str):
        tenant_id (str):
        name (str):
        api_key (str):
        email (str):
        role (Schema40):
        is_service_account (bool):
        created_at (str):
        updated_at (str):
        is_super_administrator (bool | Unset):
    """

    id: float
    sub: str
    tenant_id: str
    name: str
    api_key: str
    email: str
    role: Schema40
    is_service_account: bool
    created_at: str
    updated_at: str
    is_super_administrator: bool | Unset = UNSET

    def to_dict(self) -> dict[str, Any]:
        id = self.id

        sub = self.sub

        tenant_id = self.tenant_id

        name = self.name

        api_key = self.api_key

        email = self.email

        role = self.role.value

        is_service_account = self.is_service_account

        created_at = self.created_at

        updated_at = self.updated_at

        is_super_administrator = self.is_super_administrator

        field_dict: dict[str, Any] = {}

        field_dict.update(
            {
                "id": id,
                "sub": sub,
                "tenantId": tenant_id,
                "name": name,
                "apiKey": api_key,
                "email": email,
                "role": role,
                "isServiceAccount": is_service_account,
                "createdAt": created_at,
                "updatedAt": updated_at,
            }
        )
        if is_super_administrator is not UNSET:
            field_dict["isSuperAdministrator"] = is_super_administrator

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        id = d.pop("id")

        sub = d.pop("sub")

        tenant_id = d.pop("tenantId")

        name = d.pop("name")

        api_key = d.pop("apiKey")

        email = d.pop("email")

        role = Schema40(d.pop("role"))

        is_service_account = d.pop("isServiceAccount")

        created_at = d.pop("createdAt")

        updated_at = d.pop("updatedAt")

        is_super_administrator = d.pop("isSuperAdministrator", UNSET)

        auth_metadata_user = cls(
            id=id,
            sub=sub,
            tenant_id=tenant_id,
            name=name,
            api_key=api_key,
            email=email,
            role=role,
            is_service_account=is_service_account,
            created_at=created_at,
            updated_at=updated_at,
            is_super_administrator=is_super_administrator,
        )

        return auth_metadata_user



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast

if TYPE_CHECKING:
  from ..models.server_tool_dto import ServerToolDto





T = TypeVar("T", bound="GetMcpServersServerSlugToolsResponse200")



@_attrs_define
class GetMcpServersServerSlugToolsResponse200:
    """ 
        Attributes:
            tools (list[ServerToolDto]):
     """

    tools: list[ServerToolDto]





    def to_dict(self) -> dict[str, Any]:
        from ..models.server_tool_dto import ServerToolDto
        tools = []
        for tools_item_data in self.tools:
            tools_item = tools_item_data.to_dict()
            tools.append(tools_item)




        field_dict: dict[str, Any] = {}

        field_dict.update({
            "tools": tools,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.server_tool_dto import ServerToolDto
        d = dict(src_dict)
        tools = []
        _tools = d.pop("tools")
        for tools_item_data in (_tools):
            tools_item = ServerToolDto.from_dict(tools_item_data)



            tools.append(tools_item)


        get_mcp_servers_server_slug_tools_response_200 = cls(
            tools=tools,
        )

        return get_mcp_servers_server_slug_tools_response_200




from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define

if TYPE_CHECKING:
    from ..models.sandbox_with_status_dto_status import SandboxWithStatusDtoStatus
    from ..models.user_small_dto import UserSmallDto


T = TypeVar("T", bound="SandboxWithStatusDto")


@_attrs_define
class SandboxWithStatusDto:
    """
    Attributes:
        id (str):
        tenant_id (str):
        last_activity_at (str):
        created_at (str):
        updated_at (str):
        user (UserSmallDto):
        status (SandboxWithStatusDtoStatus):
    """

    id: str
    tenant_id: str
    last_activity_at: str
    created_at: str
    updated_at: str
    user: UserSmallDto
    status: SandboxWithStatusDtoStatus

    def to_dict(self) -> dict[str, Any]:
        id = self.id

        tenant_id = self.tenant_id

        last_activity_at = self.last_activity_at

        created_at = self.created_at

        updated_at = self.updated_at

        user = self.user.to_dict()

        status = self.status.to_dict()

        field_dict: dict[str, Any] = {}

        field_dict.update(
            {
                "id": id,
                "tenantId": tenant_id,
                "lastActivityAt": last_activity_at,
                "createdAt": created_at,
                "updatedAt": updated_at,
                "user": user,
                "status": status,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.sandbox_with_status_dto_status import SandboxWithStatusDtoStatus
        from ..models.user_small_dto import UserSmallDto

        d = dict(src_dict)
        id = d.pop("id")

        tenant_id = d.pop("tenantId")

        last_activity_at = d.pop("lastActivityAt")

        created_at = d.pop("createdAt")

        updated_at = d.pop("updatedAt")

        user = UserSmallDto.from_dict(d.pop("user"))

        status = SandboxWithStatusDtoStatus.from_dict(d.pop("status"))

        sandbox_with_status_dto = cls(
            id=id,
            tenant_id=tenant_id,
            last_activity_at=last_activity_at,
            created_at=created_at,
            updated_at=updated_at,
            user=user,
            status=status,
        )

        return sandbox_with_status_dto



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast
from typing import Literal, cast

if TYPE_CHECKING:
  from ..models.server_credentials_outh_token_set import ServerCredentialsOuthTokenSet





T = TypeVar("T", bound="ServerCredentialsOuth")



@_attrs_define
class ServerCredentialsOuth:
    """ 
        Attributes:
            type_ (Literal['oauth']):
            token_set (ServerCredentialsOuthTokenSet):
     """

    type_: Literal['oauth']
    token_set: ServerCredentialsOuthTokenSet
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.server_credentials_outh_token_set import ServerCredentialsOuthTokenSet
        type_ = self.type_

        token_set = self.token_set.to_dict()


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "type": type_,
            "tokenSet": token_set,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.server_credentials_outh_token_set import ServerCredentialsOuthTokenSet
        d = dict(src_dict)
        type_ = cast(Literal['oauth'] , d.pop("type"))
        if type_ != 'oauth':
            raise ValueError(f"type must match const 'oauth', got '{type_}'")

        token_set = ServerCredentialsOuthTokenSet.from_dict(d.pop("tokenSet"))




        server_credentials_outh = cls(
            type_=type_,
            token_set=token_set,
        )


        server_credentials_outh.additional_properties = d
        return server_credentials_outh

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any
from urllib.parse import quote

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.schema_25 import Schema25
from ...models.schema_65 import Schema65
from ...types import UNSET, Response, Unset


def _get_kwargs(
    server_slug: str,
    tool_name: str,
    *,
    body: Schema25 | Unset = UNSET,
) -> dict[str, Any]:
    headers: dict[str, Any] = {}

    _kwargs: dict[str, Any] = {
        "method": "put",
        "url": "/mcp-servers/{server_slug}/tools/{tool_name}/isEnabled".format(
            server_slug=quote(str(server_slug), safe=""),
            tool_name=quote(str(tool_name), safe=""),
        ),
    }

    if not isinstance(body, Unset):
        _kwargs["json"] = body.to_dict()

    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(*, client: AuthenticatedClient | Client, response: httpx.Response) -> Schema65 | None:
    if response.status_code == 200:
        response_200 = Schema65.from_dict(response.json())

        return response_200

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: AuthenticatedClient | Client, response: httpx.Response) -> Response[Schema65]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    server_slug: str,
    tool_name: str,
    *,
    client: AuthenticatedClient | Client,
    body: Schema25 | Unset = UNSET,
) -> Response[Schema65]:
    """
    Args:
        server_slug (str):
        tool_name (str):
        body (Schema25 | Unset):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Schema65]
    """

    kwargs = _get_kwargs(
        server_slug=server_slug,
        tool_name=tool_name,
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    server_slug: str,
    tool_name: str,
    *,
    client: AuthenticatedClient | Client,
    body: Schema25 | Unset = UNSET,
) -> Schema65 | None:
    """
    Args:
        server_slug (str):
        tool_name (str):
        body (Schema25 | Unset):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Schema65
    """

    return sync_detailed(
        server_slug=server_slug,
        tool_name=tool_name,
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    server_slug: str,
    tool_name: str,
    *,
    client: AuthenticatedClient | Client,
    body: Schema25 | Unset = UNSET,
) -> Response[Schema65]:
    """
    Args:
        server_slug (str):
        tool_name (str):
        body (Schema25 | Unset):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Schema65]
    """

    kwargs = _get_kwargs(
        server_slug=server_slug,
        tool_name=tool_name,
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    server_slug: str,
    tool_name: str,
    *,
    client: AuthenticatedClient | Client,
    body: Schema25 | Unset = UNSET,
) -> Schema65 | None:
    """
    Args:
        server_slug (str):
        tool_name (str):
        body (Schema25 | Unset):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Schema65
    """

    return (
        await asyncio_detailed(
            server_slug=server_slug,
            tool_name=tool_name,
            client=client,
            body=body,
        )
    ).parsed



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset







T = TypeVar("T", bound="TenantSamlConfiguration")



@_attrs_define
class TenantSamlConfiguration:
    """ 
        Attributes:
            is_enabled (bool):
            display_name (str):
            idp_metadata_url (str):
            idp_metadata_document (str):
            entry_point (str):
            cert (str):
            identifier_format (str):
            signature_algorithm (str):
            email_claim (str):
            first_name_claim (str):
            last_name_claim (str):
     """

    is_enabled: bool
    display_name: str
    idp_metadata_url: str
    idp_metadata_document: str
    entry_point: str
    cert: str
    identifier_format: str
    signature_algorithm: str
    email_claim: str
    first_name_claim: str
    last_name_claim: str





    def to_dict(self) -> dict[str, Any]:
        is_enabled = self.is_enabled

        display_name = self.display_name

        idp_metadata_url = self.idp_metadata_url

        idp_metadata_document = self.idp_metadata_document

        entry_point = self.entry_point

        cert = self.cert

        identifier_format = self.identifier_format

        signature_algorithm = self.signature_algorithm

        email_claim = self.email_claim

        first_name_claim = self.first_name_claim

        last_name_claim = self.last_name_claim


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "isEnabled": is_enabled,
            "displayName": display_name,
            "idpMetadataUrl": idp_metadata_url,
            "idpMetadataDocument": idp_metadata_document,
            "entryPoint": entry_point,
            "cert": cert,
            "identifierFormat": identifier_format,
            "signatureAlgorithm": signature_algorithm,
            "emailClaim": email_claim,
            "firstNameClaim": first_name_claim,
            "lastNameClaim": last_name_claim,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        is_enabled = d.pop("isEnabled")

        display_name = d.pop("displayName")

        idp_metadata_url = d.pop("idpMetadataUrl")

        idp_metadata_document = d.pop("idpMetadataDocument")

        entry_point = d.pop("entryPoint")

        cert = d.pop("cert")

        identifier_format = d.pop("identifierFormat")

        signature_algorithm = d.pop("signatureAlgorithm")

        email_claim = d.pop("emailClaim")

        first_name_claim = d.pop("firstNameClaim")

        last_name_claim = d.pop("lastNameClaim")

        tenant_saml_configuration = cls(
            is_enabled=is_enabled,
            display_name=display_name,
            idp_metadata_url=idp_metadata_url,
            idp_metadata_document=idp_metadata_document,
            entry_point=entry_point,
            cert=cert,
            identifier_format=identifier_format,
            signature_algorithm=signature_algorithm,
            email_claim=email_claim,
            first_name_claim=first_name_claim,
            last_name_claim=last_name_claim,
        )

        return tenant_saml_configuration




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset







T = TypeVar("T", bound="DeleteTeamsTeamIdClaimMappingsMappingIdResponse200")



@_attrs_define
class DeleteTeamsTeamIdClaimMappingsMappingIdResponse200:
    """ 
        Attributes:
            success (bool):
     """

    success: bool





    def to_dict(self) -> dict[str, Any]:
        success = self.success


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "success": success,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        success = d.pop("success")

        delete_teams_team_id_claim_mappings_mapping_id_response_200 = cls(
            success=success,
        )

        return delete_teams_team_id_claim_mappings_mapping_id_response_200




from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.aws_secrets_manager_configuration import AwsSecretsManagerConfiguration
    from ..models.azure_key_vault_configuration import AzureKeyVaultConfiguration
    from ..models.gcp_secret_manager_configuration import GcpSecretManagerConfiguration
    from ..models.hashi_corp_vault_configuration import HashiCorpVaultConfiguration
    from ..models.infisical_configuration import InfisicalConfiguration


T = TypeVar("T", bound="PatchSecretStoresIdBody")


@_attrs_define
class PatchSecretStoresIdBody:
    """
    Attributes:
        name (str | Unset):
        configuration (AwsSecretsManagerConfiguration | AzureKeyVaultConfiguration | GcpSecretManagerConfiguration |
            HashiCorpVaultConfiguration | InfisicalConfiguration | Unset):
        is_enabled (bool | Unset):
    """

    name: str | Unset = UNSET
    configuration: (
        AwsSecretsManagerConfiguration
        | AzureKeyVaultConfiguration
        | GcpSecretManagerConfiguration
        | HashiCorpVaultConfiguration
        | InfisicalConfiguration
        | Unset
    ) = UNSET
    is_enabled: bool | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        from ..models.aws_secrets_manager_configuration import AwsSecretsManagerConfiguration
        from ..models.gcp_secret_manager_configuration import GcpSecretManagerConfiguration
        from ..models.hashi_corp_vault_configuration import HashiCorpVaultConfiguration
        from ..models.infisical_configuration import InfisicalConfiguration

        name = self.name

        configuration: dict[str, Any] | Unset
        if isinstance(self.configuration, Unset):
            configuration = UNSET
        elif isinstance(self.configuration, AwsSecretsManagerConfiguration):
            configuration = self.configuration.to_dict()
        elif isinstance(self.configuration, GcpSecretManagerConfiguration):
            configuration = self.configuration.to_dict()
        elif isinstance(self.configuration, HashiCorpVaultConfiguration):
            configuration = self.configuration.to_dict()
        elif isinstance(self.configuration, InfisicalConfiguration):
            configuration = self.configuration.to_dict()
        else:
            configuration = self.configuration.to_dict()

        is_enabled = self.is_enabled

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if name is not UNSET:
            field_dict["name"] = name
        if configuration is not UNSET:
            field_dict["configuration"] = configuration
        if is_enabled is not UNSET:
            field_dict["isEnabled"] = is_enabled

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.aws_secrets_manager_configuration import AwsSecretsManagerConfiguration
        from ..models.azure_key_vault_configuration import AzureKeyVaultConfiguration
        from ..models.gcp_secret_manager_configuration import GcpSecretManagerConfiguration
        from ..models.hashi_corp_vault_configuration import HashiCorpVaultConfiguration
        from ..models.infisical_configuration import InfisicalConfiguration

        d = dict(src_dict)
        name = d.pop("name", UNSET)

        def _parse_configuration(
            data: object,
        ) -> (
            AwsSecretsManagerConfiguration
            | AzureKeyVaultConfiguration
            | GcpSecretManagerConfiguration
            | HashiCorpVaultConfiguration
            | InfisicalConfiguration
            | Unset
        ):
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                componentsschemas_schema38_type_0 = AwsSecretsManagerConfiguration.from_dict(data)

                return componentsschemas_schema38_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                componentsschemas_schema38_type_1 = GcpSecretManagerConfiguration.from_dict(data)

                return componentsschemas_schema38_type_1
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                componentsschemas_schema38_type_2 = HashiCorpVaultConfiguration.from_dict(data)

                return componentsschemas_schema38_type_2
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                componentsschemas_schema38_type_3 = InfisicalConfiguration.from_dict(data)

                return componentsschemas_schema38_type_3
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            if not isinstance(data, dict):
                raise TypeError()
            componentsschemas_schema38_type_4 = AzureKeyVaultConfiguration.from_dict(data)

            return componentsschemas_schema38_type_4

        configuration = _parse_configuration(d.pop("configuration", UNSET))

        is_enabled = d.pop("isEnabled", UNSET)

        patch_secret_stores_id_body = cls(
            name=name,
            configuration=configuration,
            is_enabled=is_enabled,
        )

        patch_secret_stores_id_body.additional_properties = d
        return patch_secret_stores_id_body

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class SendVerificationCodeRequestPurpose(str, Enum):
    PLAYGROUND_CONVERSION = "playground-conversion"
    SIGNUP = "signup"

    def __str__(self) -> str:
        return str(self.value)



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import Literal, cast






T = TypeVar("T", bound="HashiCorpVaultConfiguration")



@_attrs_define
class HashiCorpVaultConfiguration:
    """ 
        Attributes:
            type_ (Literal['hashicorp_vault']):
            address (str):
            token (str):
            namespace (str | Unset):
            mount_path (str | Unset):  Default: 'secret'.
     """

    type_: Literal['hashicorp_vault']
    address: str
    token: str
    namespace: str | Unset = UNSET
    mount_path: str | Unset = 'secret'
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        type_ = self.type_

        address = self.address

        token = self.token

        namespace = self.namespace

        mount_path = self.mount_path


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "type": type_,
            "address": address,
            "token": token,
        })
        if namespace is not UNSET:
            field_dict["namespace"] = namespace
        if mount_path is not UNSET:
            field_dict["mountPath"] = mount_path

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        type_ = cast(Literal['hashicorp_vault'] , d.pop("type"))
        if type_ != 'hashicorp_vault':
            raise ValueError(f"type must match const 'hashicorp_vault', got '{type_}'")

        address = d.pop("address")

        token = d.pop("token")

        namespace = d.pop("namespace", UNSET)

        mount_path = d.pop("mountPath", UNSET)

        hashi_corp_vault_configuration = cls(
            type_=type_,
            address=address,
            token=token,
            namespace=namespace,
            mount_path=mount_path,
        )


        hashi_corp_vault_configuration.additional_properties = d
        return hashi_corp_vault_configuration

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define

T = TypeVar("T", bound="GetSandboxIdAuditLogsIdResponse200Pagination")


@_attrs_define
class GetSandboxIdAuditLogsIdResponse200Pagination:
    """
    Attributes:
        page (float):
        limit (float):
        total (float):
        total_pages (float):
        has_next (bool):
        has_prev (bool):
    """

    page: float
    limit: float
    total: float
    total_pages: float
    has_next: bool
    has_prev: bool

    def to_dict(self) -> dict[str, Any]:
        page = self.page

        limit = self.limit

        total = self.total

        total_pages = self.total_pages

        has_next = self.has_next

        has_prev = self.has_prev

        field_dict: dict[str, Any] = {}

        field_dict.update(
            {
                "page": page,
                "limit": limit,
                "total": total,
                "totalPages": total_pages,
                "hasNext": has_next,
                "hasPrev": has_prev,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        page = d.pop("page")

        limit = d.pop("limit")

        total = d.pop("total")

        total_pages = d.pop("totalPages")

        has_next = d.pop("hasNext")

        has_prev = d.pop("hasPrev")

        get_sandbox_id_audit_logs_id_response_200_pagination = cls(
            page=page,
            limit=limit,
            total=total,
            total_pages=total_pages,
            has_next=has_next,
            has_prev=has_prev,
        )

        return get_sandbox_id_audit_logs_id_response_200_pagination



from http import HTTPStatus
from typing import Any, cast
from urllib.parse import quote

import httpx

from ...client import AuthenticatedClient, Client
from ...types import Response, UNSET
from ... import errors

from ...models.put_users_me_response_200 import PutUsersMeResponse200
from ...models.update_user_me_request import UpdateUserMeRequest
from ...types import UNSET, Unset
from typing import cast



def _get_kwargs(
    *,
    body: UpdateUserMeRequest | Unset = UNSET,

) -> dict[str, Any]:
    headers: dict[str, Any] = {}


    

    

    _kwargs: dict[str, Any] = {
        "method": "put",
        "url": "/users/me",
    }

    
    if not isinstance(body, Unset):
        _kwargs["json"] = body.to_dict()


    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs



def _parse_response(*, client: AuthenticatedClient | Client, response: httpx.Response) -> PutUsersMeResponse200 | None:
    if response.status_code == 200:
        response_200 = PutUsersMeResponse200.from_dict(response.json())



        return response_200

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: AuthenticatedClient | Client, response: httpx.Response) -> Response[PutUsersMeResponse200]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient | Client,
    body: UpdateUserMeRequest | Unset = UNSET,

) -> Response[PutUsersMeResponse200]:
    """  Update the current authenticated user

    Args:
        body (UpdateUserMeRequest | Unset):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[PutUsersMeResponse200]
     """


    kwargs = _get_kwargs(
        body=body,

    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)

def sync(
    *,
    client: AuthenticatedClient | Client,
    body: UpdateUserMeRequest | Unset = UNSET,

) -> PutUsersMeResponse200 | None:
    """  Update the current authenticated user

    Args:
        body (UpdateUserMeRequest | Unset):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        PutUsersMeResponse200
     """


    return sync_detailed(
        client=client,
body=body,

    ).parsed

async def asyncio_detailed(
    *,
    client: AuthenticatedClient | Client,
    body: UpdateUserMeRequest | Unset = UNSET,

) -> Response[PutUsersMeResponse200]:
    """  Update the current authenticated user

    Args:
        body (UpdateUserMeRequest | Unset):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[PutUsersMeResponse200]
     """


    kwargs = _get_kwargs(
        body=body,

    )

    response = await client.get_async_httpx_client().request(
        **kwargs
    )

    return _build_response(client=client, response=response)

async def asyncio(
    *,
    client: AuthenticatedClient | Client,
    body: UpdateUserMeRequest | Unset = UNSET,

) -> PutUsersMeResponse200 | None:
    """  Update the current authenticated user

    Args:
        body (UpdateUserMeRequest | Unset):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        PutUsersMeResponse200
     """


    return (await asyncio_detailed(
        client=client,
body=body,

    )).parsed



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define

from ..models.schema_66 import Schema66

T = TypeVar("T", bound="ServerMemberType0")


@_attrs_define
class ServerMemberType0:
    """
    Attributes:
        tenant_id (str):
        server_id (float):
        role (Schema66):
        created_at (str):
        updated_at (str):
        user_id (float):
        team_id (None):
    """

    tenant_id: str
    server_id: float
    role: Schema66
    created_at: str
    updated_at: str
    user_id: float
    team_id: None

    def to_dict(self) -> dict[str, Any]:
        tenant_id = self.tenant_id

        server_id = self.server_id

        role = self.role.value

        created_at = self.created_at

        updated_at = self.updated_at

        user_id = self.user_id

        team_id = self.team_id

        field_dict: dict[str, Any] = {}

        field_dict.update(
            {
                "tenantId": tenant_id,
                "serverId": server_id,
                "role": role,
                "createdAt": created_at,
                "updatedAt": updated_at,
                "userId": user_id,
                "teamId": team_id,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        tenant_id = d.pop("tenantId")

        server_id = d.pop("serverId")

        role = Schema66(d.pop("role"))

        created_at = d.pop("createdAt")

        updated_at = d.pop("updatedAt")

        user_id = d.pop("userId")

        team_id = d.pop("teamId")

        server_member_type_0 = cls(
            tenant_id=tenant_id,
            server_id=server_id,
            role=role,
            created_at=created_at,
            updated_at=updated_at,
            user_id=user_id,
            team_id=team_id,
        )

        return server_member_type_0



from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, Literal, TypeVar, cast

from attrs import define as _attrs_define

from ..models.mcp_audit_log_verbosity import McpAuditLogVerbosity
from ..models.schema_66 import Schema66

if TYPE_CHECKING:
    from ..models.tenant_oidc_configuration import TenantOidcConfiguration
    from ..models.tenant_saml_configuration import TenantSamlConfiguration


T = TypeVar("T", bound="TenantDto")


@_attrs_define
class TenantDto:
    """
    Attributes:
        id (str):
        is_playground (bool):
        display_name (str):
        upstream_oidc_configuration (None | TenantOidcConfiguration):
        upstream_saml_configuration (None | TenantSamlConfiguration):
        is_upstream_oidc_tokens_trusted (bool):
        is_automatic_seat_increase_enabled (bool):
        is_mcp_authorization_api_key_enabled (bool):
        grant_permissions_new_tool_policy (bool):
        allow_member_add_remote_servers (bool):
        allow_member_add_local_servers (bool):
        allow_member_add_hosted_servers (bool):
        is_google_refresh_token_saving_enabled (bool):
        member_default_role (Literal['none'] | Schema66):
        mcp_audit_log_level (McpAuditLogVerbosity):
    """

    id: str
    is_playground: bool
    display_name: str
    upstream_oidc_configuration: None | TenantOidcConfiguration
    upstream_saml_configuration: None | TenantSamlConfiguration
    is_upstream_oidc_tokens_trusted: bool
    is_automatic_seat_increase_enabled: bool
    is_mcp_authorization_api_key_enabled: bool
    grant_permissions_new_tool_policy: bool
    allow_member_add_remote_servers: bool
    allow_member_add_local_servers: bool
    allow_member_add_hosted_servers: bool
    is_google_refresh_token_saving_enabled: bool
    member_default_role: Literal["none"] | Schema66
    mcp_audit_log_level: McpAuditLogVerbosity

    def to_dict(self) -> dict[str, Any]:
        from ..models.tenant_oidc_configuration import TenantOidcConfiguration
        from ..models.tenant_saml_configuration import TenantSamlConfiguration

        id = self.id

        is_playground = self.is_playground

        display_name = self.display_name

        upstream_oidc_configuration: dict[str, Any] | None
        if isinstance(self.upstream_oidc_configuration, TenantOidcConfiguration):
            upstream_oidc_configuration = self.upstream_oidc_configuration.to_dict()
        else:
            upstream_oidc_configuration = self.upstream_oidc_configuration

        upstream_saml_configuration: dict[str, Any] | None
        if isinstance(self.upstream_saml_configuration, TenantSamlConfiguration):
            upstream_saml_configuration = self.upstream_saml_configuration.to_dict()
        else:
            upstream_saml_configuration = self.upstream_saml_configuration

        is_upstream_oidc_tokens_trusted = self.is_upstream_oidc_tokens_trusted

        is_automatic_seat_increase_enabled = self.is_automatic_seat_increase_enabled

        is_mcp_authorization_api_key_enabled = self.is_mcp_authorization_api_key_enabled

        grant_permissions_new_tool_policy = self.grant_permissions_new_tool_policy

        allow_member_add_remote_servers = self.allow_member_add_remote_servers

        allow_member_add_local_servers = self.allow_member_add_local_servers

        allow_member_add_hosted_servers = self.allow_member_add_hosted_servers

        is_google_refresh_token_saving_enabled = self.is_google_refresh_token_saving_enabled

        member_default_role: Literal["none"] | str
        if isinstance(self.member_default_role, Schema66):
            member_default_role = self.member_default_role.value
        else:
            member_default_role = self.member_default_role

        mcp_audit_log_level = self.mcp_audit_log_level.value

        field_dict: dict[str, Any] = {}

        field_dict.update(
            {
                "id": id,
                "isPlayground": is_playground,
                "displayName": display_name,
                "upstreamOidcConfiguration": upstream_oidc_configuration,
                "upstreamSamlConfiguration": upstream_saml_configuration,
                "isUpstreamOidcTokensTrusted": is_upstream_oidc_tokens_trusted,
                "isAutomaticSeatIncreaseEnabled": is_automatic_seat_increase_enabled,
                "isMcpAuthorizationApiKeyEnabled": is_mcp_authorization_api_key_enabled,
                "grantPermissionsNewToolPolicy": grant_permissions_new_tool_policy,
                "allowMemberAddRemoteServers": allow_member_add_remote_servers,
                "allowMemberAddLocalServers": allow_member_add_local_servers,
                "allowMemberAddHostedServers": allow_member_add_hosted_servers,
                "isGoogleRefreshTokenSavingEnabled": is_google_refresh_token_saving_enabled,
                "memberDefaultRole": member_default_role,
                "mcpAuditLogLevel": mcp_audit_log_level,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.tenant_oidc_configuration import TenantOidcConfiguration
        from ..models.tenant_saml_configuration import TenantSamlConfiguration

        d = dict(src_dict)
        id = d.pop("id")

        is_playground = d.pop("isPlayground")

        display_name = d.pop("displayName")

        def _parse_upstream_oidc_configuration(data: object) -> None | TenantOidcConfiguration:
            if data is None:
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                upstream_oidc_configuration_type_0 = TenantOidcConfiguration.from_dict(data)

                return upstream_oidc_configuration_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(None | TenantOidcConfiguration, data)

        upstream_oidc_configuration = _parse_upstream_oidc_configuration(d.pop("upstreamOidcConfiguration"))

        def _parse_upstream_saml_configuration(data: object) -> None | TenantSamlConfiguration:
            if data is None:
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                upstream_saml_configuration_type_0 = TenantSamlConfiguration.from_dict(data)

                return upstream_saml_configuration_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(None | TenantSamlConfiguration, data)

        upstream_saml_configuration = _parse_upstream_saml_configuration(d.pop("upstreamSamlConfiguration"))

        is_upstream_oidc_tokens_trusted = d.pop("isUpstreamOidcTokensTrusted")

        is_automatic_seat_increase_enabled = d.pop("isAutomaticSeatIncreaseEnabled")

        is_mcp_authorization_api_key_enabled = d.pop("isMcpAuthorizationApiKeyEnabled")

        grant_permissions_new_tool_policy = d.pop("grantPermissionsNewToolPolicy")

        allow_member_add_remote_servers = d.pop("allowMemberAddRemoteServers")

        allow_member_add_local_servers = d.pop("allowMemberAddLocalServers")

        allow_member_add_hosted_servers = d.pop("allowMemberAddHostedServers")

        is_google_refresh_token_saving_enabled = d.pop("isGoogleRefreshTokenSavingEnabled")

        def _parse_member_default_role(data: object) -> Literal["none"] | Schema66:
            try:
                if not isinstance(data, str):
                    raise TypeError()
                member_default_role_type_0 = Schema66(data)

                return member_default_role_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            member_default_role_type_1 = cast(Literal["none"], data)
            if member_default_role_type_1 != "none":
                raise ValueError(
                    f"memberDefaultRole_type_1 must match const 'none', got '{member_default_role_type_1}'"
                )
            return member_default_role_type_1

        member_default_role = _parse_member_default_role(d.pop("memberDefaultRole"))

        mcp_audit_log_level = McpAuditLogVerbosity(d.pop("mcpAuditLogLevel"))

        tenant_dto = cls(
            id=id,
            is_playground=is_playground,
            display_name=display_name,
            upstream_oidc_configuration=upstream_oidc_configuration,
            upstream_saml_configuration=upstream_saml_configuration,
            is_upstream_oidc_tokens_trusted=is_upstream_oidc_tokens_trusted,
            is_automatic_seat_increase_enabled=is_automatic_seat_increase_enabled,
            is_mcp_authorization_api_key_enabled=is_mcp_authorization_api_key_enabled,
            grant_permissions_new_tool_policy=grant_permissions_new_tool_policy,
            allow_member_add_remote_servers=allow_member_add_remote_servers,
            allow_member_add_local_servers=allow_member_add_local_servers,
            allow_member_add_hosted_servers=allow_member_add_hosted_servers,
            is_google_refresh_token_saving_enabled=is_google_refresh_token_saving_enabled,
            member_default_role=member_default_role,
            mcp_audit_log_level=mcp_audit_log_level,
        )

        return tenant_dto



from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define

if TYPE_CHECKING:
    from ..models.server_dto import ServerDto
    from ..models.server_file import ServerFile


T = TypeVar("T", bound="Schema64")


@_attrs_define
class Schema64:
    """
    Attributes:
        server (ServerDto):
        files (list[ServerFile]):
    """

    server: ServerDto
    files: list[ServerFile]

    def to_dict(self) -> dict[str, Any]:
        server = self.server.to_dict()

        files = []
        for files_item_data in self.files:
            files_item = files_item_data.to_dict()
            files.append(files_item)

        field_dict: dict[str, Any] = {}

        field_dict.update(
            {
                "server": server,
                "files": files,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.server_dto import ServerDto
        from ..models.server_file import ServerFile

        d = dict(src_dict)
        server = ServerDto.from_dict(d.pop("server"))

        files = []
        _files = d.pop("files")
        for files_item_data in _files:
            files_item = ServerFile.from_dict(files_item_data)

            files.append(files_item)

        schema_64 = cls(
            server=server,
            files=files,
        )

        return schema_64



from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define

if TYPE_CHECKING:
    from ..models.team_member import TeamMember
    from ..models.user import User


T = TypeVar("T", bound="GetTeamsTeamIdMembersResponse200MembersItem")


@_attrs_define
class GetTeamsTeamIdMembersResponse200MembersItem:
    """
    Attributes:
        member (TeamMember):
        user (User):
    """

    member: TeamMember
    user: User

    def to_dict(self) -> dict[str, Any]:
        member = self.member.to_dict()

        user = self.user.to_dict()

        field_dict: dict[str, Any] = {}

        field_dict.update(
            {
                "member": member,
                "user": user,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.team_member import TeamMember
        from ..models.user import User

        d = dict(src_dict)
        member = TeamMember.from_dict(d.pop("member"))

        user = User.from_dict(d.pop("user"))

        get_teams_team_id_members_response_200_members_item = cls(
            member=member,
            user=user,
        )

        return get_teams_team_id_members_response_200_members_item



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import Literal, cast






T = TypeVar("T", bound="HttpStreamingTransportConfig")



@_attrs_define
class HttpStreamingTransportConfig:
    """ 
        Attributes:
            type_ (Literal['httpstreaming']):
            url (str):
            headers (list[list[str]] | Unset):
     """

    type_: Literal['httpstreaming']
    url: str
    headers: list[list[str]] | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        type_ = self.type_

        url = self.url

        headers: list[list[str]] | Unset = UNSET
        if not isinstance(self.headers, Unset):
            headers = []
            for componentsschemas_schema9_item_data in self.headers:
                componentsschemas_schema9_item = []
                for componentsschemas_schema9_item_item_data in componentsschemas_schema9_item_data:
                    componentsschemas_schema9_item_item: str
                    componentsschemas_schema9_item_item = componentsschemas_schema9_item_item_data
                    componentsschemas_schema9_item.append(componentsschemas_schema9_item_item)


                headers.append(componentsschemas_schema9_item)




        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "type": type_,
            "url": url,
        })
        if headers is not UNSET:
            field_dict["headers"] = headers

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        type_ = cast(Literal['httpstreaming'] , d.pop("type"))
        if type_ != 'httpstreaming':
            raise ValueError(f"type must match const 'httpstreaming', got '{type_}'")

        url = d.pop("url")

        _headers = d.pop("headers", UNSET)
        headers: list[list[str]] | Unset = UNSET
        if _headers is not UNSET:
            headers = []
            for componentsschemas_schema9_item_data in _headers:
                componentsschemas_schema9_item = []
                _componentsschemas_schema9_item = componentsschemas_schema9_item_data
                for componentsschemas_schema9_item_item_data in (_componentsschemas_schema9_item):
                    def _parse_componentsschemas_schema9_item_item(data: object) -> str:
                        return cast(str, data)

                    componentsschemas_schema9_item_item = _parse_componentsschemas_schema9_item_item(componentsschemas_schema9_item_item_data)

                    componentsschemas_schema9_item.append(componentsschemas_schema9_item_item)

                headers.append(componentsschemas_schema9_item)


        http_streaming_transport_config = cls(
            type_=type_,
            url=url,
            headers=headers,
        )


        http_streaming_transport_config.additional_properties = d
        return http_streaming_transport_config

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define

if TYPE_CHECKING:
    from ..models.team_with_member_count import TeamWithMemberCount


T = TypeVar("T", bound="Schema68")


@_attrs_define
class Schema68:
    """
    Attributes:
        team (TeamWithMemberCount):
    """

    team: TeamWithMemberCount

    def to_dict(self) -> dict[str, Any]:
        team = self.team.to_dict()

        field_dict: dict[str, Any] = {}

        field_dict.update(
            {
                "team": team,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.team_with_member_count import TeamWithMemberCount

        d = dict(src_dict)
        team = TeamWithMemberCount.from_dict(d.pop("team"))

        schema_68 = cls(
            team=team,
        )

        return schema_68



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import Literal, cast






T = TypeVar("T", bound="AwsSecretsManagerConfiguration")



@_attrs_define
class AwsSecretsManagerConfiguration:
    """ 
        Attributes:
            type_ (Literal['aws_secrets_manager']):
            region (str):
            access_key_id (str):
            secret_access_key (str):
     """

    type_: Literal['aws_secrets_manager']
    region: str
    access_key_id: str
    secret_access_key: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        type_ = self.type_

        region = self.region

        access_key_id = self.access_key_id

        secret_access_key = self.secret_access_key


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "type": type_,
            "region": region,
            "accessKeyId": access_key_id,
            "secretAccessKey": secret_access_key,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        type_ = cast(Literal['aws_secrets_manager'] , d.pop("type"))
        if type_ != 'aws_secrets_manager':
            raise ValueError(f"type must match const 'aws_secrets_manager', got '{type_}'")

        region = d.pop("region")

        access_key_id = d.pop("accessKeyId")

        secret_access_key = d.pop("secretAccessKey")

        aws_secrets_manager_configuration = cls(
            type_=type_,
            region=region,
            access_key_id=access_key_id,
            secret_access_key=secret_access_key,
        )


        aws_secrets_manager_configuration.additional_properties = d
        return aws_secrets_manager_configuration

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast






T = TypeVar("T", bound="GetMcpServersServerSlugCredentialsServerApikeysResponse200")



@_attrs_define
class GetMcpServersServerSlugCredentialsServerApikeysResponse200:
    """ 
        Attributes:
            apikeys (list[list[str]]):
     """

    apikeys: list[list[str]]





    def to_dict(self) -> dict[str, Any]:
        apikeys = []
        for apikeys_item_data in self.apikeys:
            apikeys_item = []
            for apikeys_item_item_data in apikeys_item_data:
                apikeys_item_item: str
                apikeys_item_item = apikeys_item_item_data
                apikeys_item.append(apikeys_item_item)


            apikeys.append(apikeys_item)




        field_dict: dict[str, Any] = {}

        field_dict.update({
            "apikeys": apikeys,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        apikeys = []
        _apikeys = d.pop("apikeys")
        for apikeys_item_data in (_apikeys):
            apikeys_item = []
            _apikeys_item = apikeys_item_data
            for apikeys_item_item_data in (_apikeys_item):
                def _parse_apikeys_item_item(data: object) -> str:
                    return cast(str, data)

                apikeys_item_item = _parse_apikeys_item_item(apikeys_item_item_data)

                apikeys_item.append(apikeys_item_item)

            apikeys.append(apikeys_item)


        get_mcp_servers_server_slug_credentials_server_apikeys_response_200 = cls(
            apikeys=apikeys,
        )

        return get_mcp_servers_server_slug_credentials_server_apikeys_response_200




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import Literal, cast






T = TypeVar("T", bound="GcpSecretManagerConfigurationOutput")



@_attrs_define
class GcpSecretManagerConfigurationOutput:
    """ 
        Attributes:
            type_ (Literal['gcp_secret_manager']):
            project_id (str):
            service_account_key (str):
     """

    type_: Literal['gcp_secret_manager']
    project_id: str
    service_account_key: str





    def to_dict(self) -> dict[str, Any]:
        type_ = self.type_

        project_id = self.project_id

        service_account_key = self.service_account_key


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "type": type_,
            "projectId": project_id,
            "serviceAccountKey": service_account_key,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        type_ = cast(Literal['gcp_secret_manager'] , d.pop("type"))
        if type_ != 'gcp_secret_manager':
            raise ValueError(f"type must match const 'gcp_secret_manager', got '{type_}'")

        project_id = d.pop("projectId")

        service_account_key = d.pop("serviceAccountKey")

        gcp_secret_manager_configuration_output = cls(
            type_=type_,
            project_id=project_id,
            service_account_key=service_account_key,
        )

        return gcp_secret_manager_configuration_output




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset






T = TypeVar("T", bound="ServerCredentialsOuthTokenSet")



@_attrs_define
class ServerCredentialsOuthTokenSet:
    """ 
        Attributes:
            access_token (str):
            access_token_expires_at (float | Unset):
            id_token (str | Unset):
            refresh_token (str | Unset):
     """

    access_token: str
    access_token_expires_at: float | Unset = UNSET
    id_token: str | Unset = UNSET
    refresh_token: str | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        access_token = self.access_token

        access_token_expires_at = self.access_token_expires_at

        id_token = self.id_token

        refresh_token = self.refresh_token


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "accessToken": access_token,
        })
        if access_token_expires_at is not UNSET:
            field_dict["accessTokenExpiresAt"] = access_token_expires_at
        if id_token is not UNSET:
            field_dict["idToken"] = id_token
        if refresh_token is not UNSET:
            field_dict["refreshToken"] = refresh_token

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        access_token = d.pop("accessToken")

        access_token_expires_at = d.pop("accessTokenExpiresAt", UNSET)

        id_token = d.pop("idToken", UNSET)

        refresh_token = d.pop("refreshToken", UNSET)

        server_credentials_outh_token_set = cls(
            access_token=access_token,
            access_token_expires_at=access_token_expires_at,
            id_token=id_token,
            refresh_token=refresh_token,
        )


        server_credentials_outh_token_set.additional_properties = d
        return server_credentials_outh_token_set

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast

if TYPE_CHECKING:
  from ..models.profile_details_dto import ProfileDetailsDto





T = TypeVar("T", bound="PostProfilesResponse200")



@_attrs_define
class PostProfilesResponse200:
    """ 
        Attributes:
            profile (ProfileDetailsDto):
     """

    profile: ProfileDetailsDto





    def to_dict(self) -> dict[str, Any]:
        from ..models.profile_details_dto import ProfileDetailsDto
        profile = self.profile.to_dict()


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "profile": profile,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.profile_details_dto import ProfileDetailsDto
        d = dict(src_dict)
        profile = ProfileDetailsDto.from_dict(d.pop("profile"))




        post_profiles_response_200 = cls(
            profile=profile,
        )

        return post_profiles_response_200




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast

if TYPE_CHECKING:
  from ..models.server_credentials_dto import ServerCredentialsDto





T = TypeVar("T", bound="GetMcpServersServerSlugCredentialsResponse200")



@_attrs_define
class GetMcpServersServerSlugCredentialsResponse200:
    """ 
        Attributes:
            credentials (list[ServerCredentialsDto]):
     """

    credentials: list[ServerCredentialsDto]





    def to_dict(self) -> dict[str, Any]:
        from ..models.server_credentials_dto import ServerCredentialsDto
        credentials = []
        for credentials_item_data in self.credentials:
            credentials_item = credentials_item_data.to_dict()
            credentials.append(credentials_item)




        field_dict: dict[str, Any] = {}

        field_dict.update({
            "credentials": credentials,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.server_credentials_dto import ServerCredentialsDto
        d = dict(src_dict)
        credentials = []
        _credentials = d.pop("credentials")
        for credentials_item_data in (_credentials):
            credentials_item = ServerCredentialsDto.from_dict(credentials_item_data)



            credentials.append(credentials_item)


        get_mcp_servers_server_slug_credentials_response_200 = cls(
            credentials=credentials,
        )

        return get_mcp_servers_server_slug_credentials_response_200




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast

if TYPE_CHECKING:
  from ..models.profile_claim_mapping import ProfileClaimMapping





T = TypeVar("T", bound="PostProfilesProfileIdClaimMappingsResponse200")



@_attrs_define
class PostProfilesProfileIdClaimMappingsResponse200:
    """ 
        Attributes:
            claim_mapping (ProfileClaimMapping):
     """

    claim_mapping: ProfileClaimMapping





    def to_dict(self) -> dict[str, Any]:
        from ..models.profile_claim_mapping import ProfileClaimMapping
        claim_mapping = self.claim_mapping.to_dict()


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "claimMapping": claim_mapping,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.profile_claim_mapping import ProfileClaimMapping
        d = dict(src_dict)
        claim_mapping = ProfileClaimMapping.from_dict(d.pop("claimMapping"))




        post_profiles_profile_id_claim_mappings_response_200 = cls(
            claim_mapping=claim_mapping,
        )

        return post_profiles_profile_id_claim_mappings_response_200




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast

if TYPE_CHECKING:
  from ..models.auth_metadata_quota_enabled_servers import AuthMetadataQuotaEnabledServers





T = TypeVar("T", bound="AuthMetadataQuota")



@_attrs_define
class AuthMetadataQuota:
    """ 
        Attributes:
            enabled_servers (AuthMetadataQuotaEnabledServers):
     """

    enabled_servers: AuthMetadataQuotaEnabledServers





    def to_dict(self) -> dict[str, Any]:
        from ..models.auth_metadata_quota_enabled_servers import AuthMetadataQuotaEnabledServers
        enabled_servers = self.enabled_servers.to_dict()


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "enabledServers": enabled_servers,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.auth_metadata_quota_enabled_servers import AuthMetadataQuotaEnabledServers
        d = dict(src_dict)
        enabled_servers = AuthMetadataQuotaEnabledServers.from_dict(d.pop("enabledServers"))




        auth_metadata_quota = cls(
            enabled_servers=enabled_servers,
        )

        return auth_metadata_quota




from http import HTTPStatus
from typing import Any, cast
from urllib.parse import quote

import httpx

from ...client import AuthenticatedClient, Client
from ...types import Response, UNSET
from ... import errors

from ...models.get_mcp_servers_server_slug_credentials_response_200 import GetMcpServersServerSlugCredentialsResponse200
from ...types import UNSET, Unset
from typing import cast



def _get_kwargs(
    server_slug: str,
    *,
    all_: str | Unset = UNSET,

) -> dict[str, Any]:
    

    

    params: dict[str, Any] = {}

    params["all"] = all_


    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}


    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/mcp-servers/{server_slug}/credentials".format(server_slug=quote(str(server_slug), safe=""),),
        "params": params,
    }


    return _kwargs



def _parse_response(*, client: AuthenticatedClient | Client, response: httpx.Response) -> GetMcpServersServerSlugCredentialsResponse200 | None:
    if response.status_code == 200:
        response_200 = GetMcpServersServerSlugCredentialsResponse200.from_dict(response.json())



        return response_200

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: AuthenticatedClient | Client, response: httpx.Response) -> Response[GetMcpServersServerSlugCredentialsResponse200]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    server_slug: str,
    *,
    client: AuthenticatedClient | Client,
    all_: str | Unset = UNSET,

) -> Response[GetMcpServersServerSlugCredentialsResponse200]:
    """  Get a list of all the credentials associated with the server (user-, profile-, and server-scoped
    credentials).

    Args:
        server_slug (str):
        all_ (str | Unset): If "true", retrieves credentials for all users (only available for
            admins).

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GetMcpServersServerSlugCredentialsResponse200]
     """


    kwargs = _get_kwargs(
        server_slug=server_slug,
all_=all_,

    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)

def sync(
    server_slug: str,
    *,
    client: AuthenticatedClient | Client,
    all_: str | Unset = UNSET,

) -> GetMcpServersServerSlugCredentialsResponse200 | None:
    """  Get a list of all the credentials associated with the server (user-, profile-, and server-scoped
    credentials).

    Args:
        server_slug (str):
        all_ (str | Unset): If "true", retrieves credentials for all users (only available for
            admins).

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GetMcpServersServerSlugCredentialsResponse200
     """


    return sync_detailed(
        server_slug=server_slug,
client=client,
all_=all_,

    ).parsed

async def asyncio_detailed(
    server_slug: str,
    *,
    client: AuthenticatedClient | Client,
    all_: str | Unset = UNSET,

) -> Response[GetMcpServersServerSlugCredentialsResponse200]:
    """  Get a list of all the credentials associated with the server (user-, profile-, and server-scoped
    credentials).

    Args:
        server_slug (str):
        all_ (str | Unset): If "true", retrieves credentials for all users (only available for
            admins).

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GetMcpServersServerSlugCredentialsResponse200]
     """


    kwargs = _get_kwargs(
        server_slug=server_slug,
all_=all_,

    )

    response = await client.get_async_httpx_client().request(
        **kwargs
    )

    return _build_response(client=client, response=response)

async def asyncio(
    server_slug: str,
    *,
    client: AuthenticatedClient | Client,
    all_: str | Unset = UNSET,

) -> GetMcpServersServerSlugCredentialsResponse200 | None:
    """  Get a list of all the credentials associated with the server (user-, profile-, and server-scoped
    credentials).

    Args:
        server_slug (str):
        all_ (str | Unset): If "true", retrieves credentials for all users (only available for
            admins).

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GetMcpServersServerSlugCredentialsResponse200
     """


    return (await asyncio_detailed(
        server_slug=server_slug,
client=client,
all_=all_,

    )).parsed



from enum import Enum

class UpdateServerRequestOauthClientConfigurationType0GrantType(str, Enum):
    AUTHORIZATION_CODE = "authorization_code"
    DEVICE_CODE = "device_code"

    def __str__(self) -> str:
        return str(self.value)



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset







T = TypeVar("T", bound="DeleteUsersUserSubPersonalAccessTokensPatIdResponse200")



@_attrs_define
class DeleteUsersUserSubPersonalAccessTokensPatIdResponse200:
    """ 
     """






    def to_dict(self) -> dict[str, Any]:
        
        field_dict: dict[str, Any] = {}


        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        delete_users_user_sub_personal_access_tokens_pat_id_response_200 = cls(
        )

        return delete_users_user_sub_personal_access_tokens_pat_id_response_200




from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define

if TYPE_CHECKING:
    from ..models.get_user_me_response_user import GetUserMeResponseUser
    from ..models.user_identity import UserIdentity


T = TypeVar("T", bound="GetUserMeResponse")


@_attrs_define
class GetUserMeResponse:
    """
    Attributes:
        user (GetUserMeResponseUser):
        identities (list[UserIdentity]):
    """

    user: GetUserMeResponseUser
    identities: list[UserIdentity]

    def to_dict(self) -> dict[str, Any]:
        user = self.user.to_dict()

        identities = []
        for identities_item_data in self.identities:
            identities_item = identities_item_data.to_dict()
            identities.append(identities_item)

        field_dict: dict[str, Any] = {}

        field_dict.update(
            {
                "user": user,
                "identities": identities,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.get_user_me_response_user import GetUserMeResponseUser
        from ..models.user_identity import UserIdentity

        d = dict(src_dict)
        user = GetUserMeResponseUser.from_dict(d.pop("user"))

        identities = []
        _identities = d.pop("identities")
        for identities_item_data in _identities:
            identities_item = UserIdentity.from_dict(identities_item_data)

            identities.append(identities_item)

        get_user_me_response = cls(
            user=user,
            identities=identities,
        )

        return get_user_me_response



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import Literal, cast






T = TypeVar("T", bound="HttpStreamingTransportConfigOutput")



@_attrs_define
class HttpStreamingTransportConfigOutput:
    """ 
        Attributes:
            type_ (Literal['httpstreaming']):
            url (str):
            headers (list[list[str]] | Unset):
     """

    type_: Literal['httpstreaming']
    url: str
    headers: list[list[str]] | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        type_ = self.type_

        url = self.url

        headers: list[list[str]] | Unset = UNSET
        if not isinstance(self.headers, Unset):
            headers = []
            for headers_item_data in self.headers:
                headers_item = []
                for headers_item_item_data in headers_item_data:
                    headers_item_item: str
                    headers_item_item = headers_item_item_data
                    headers_item.append(headers_item_item)


                headers.append(headers_item)




        field_dict: dict[str, Any] = {}

        field_dict.update({
            "type": type_,
            "url": url,
        })
        if headers is not UNSET:
            field_dict["headers"] = headers

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        type_ = cast(Literal['httpstreaming'] , d.pop("type"))
        if type_ != 'httpstreaming':
            raise ValueError(f"type must match const 'httpstreaming', got '{type_}'")

        url = d.pop("url")

        _headers = d.pop("headers", UNSET)
        headers: list[list[str]] | Unset = UNSET
        if _headers is not UNSET:
            headers = []
            for headers_item_data in _headers:
                headers_item = []
                _headers_item = headers_item_data
                for headers_item_item_data in (_headers_item):
                    def _parse_headers_item_item(data: object) -> str:
                        return cast(str, data)

                    headers_item_item = _parse_headers_item_item(headers_item_item_data)

                    headers_item.append(headers_item_item)

                headers.append(headers_item)


        http_streaming_transport_config_output = cls(
            type_=type_,
            url=url,
            headers=headers,
        )

        return http_streaming_transport_config_output




from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define

if TYPE_CHECKING:
    from ..models.sandbox_dto import SandboxDto


T = TypeVar("T", bound="ListSandboxesResponse")


@_attrs_define
class ListSandboxesResponse:
    """
    Attributes:
        sandboxes (list[SandboxDto]):
    """

    sandboxes: list[SandboxDto]

    def to_dict(self) -> dict[str, Any]:
        sandboxes = []
        for sandboxes_item_data in self.sandboxes:
            sandboxes_item = sandboxes_item_data.to_dict()
            sandboxes.append(sandboxes_item)

        field_dict: dict[str, Any] = {}

        field_dict.update(
            {
                "sandboxes": sandboxes,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.sandbox_dto import SandboxDto

        d = dict(src_dict)
        sandboxes = []
        _sandboxes = d.pop("sandboxes")
        for sandboxes_item_data in _sandboxes:
            sandboxes_item = SandboxDto.from_dict(sandboxes_item_data)

            sandboxes.append(sandboxes_item)

        list_sandboxes_response = cls(
            sandboxes=sandboxes,
        )

        return list_sandboxes_response



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, cast

from attrs import define as _attrs_define

from ..models.schema_69 import Schema69

T = TypeVar("T", bound="TeamInvitation")


@_attrs_define
class TeamInvitation:
    """
    Attributes:
        id (str):
        team_id (str):
        tenant_id (str):
        inviter_user_id (float | None):
        email (str):
        role (Schema69):
        token (str):
        expires_at (str):
        accepted_at (None | str):
        created_at (str):
        updated_at (str):
    """

    id: str
    team_id: str
    tenant_id: str
    inviter_user_id: float | None
    email: str
    role: Schema69
    token: str
    expires_at: str
    accepted_at: None | str
    created_at: str
    updated_at: str

    def to_dict(self) -> dict[str, Any]:
        id = self.id

        team_id = self.team_id

        tenant_id = self.tenant_id

        inviter_user_id: float | None
        inviter_user_id = self.inviter_user_id

        email = self.email

        role = self.role.value

        token = self.token

        expires_at = self.expires_at

        accepted_at: None | str
        accepted_at = self.accepted_at

        created_at = self.created_at

        updated_at = self.updated_at

        field_dict: dict[str, Any] = {}

        field_dict.update(
            {
                "id": id,
                "teamId": team_id,
                "tenantId": tenant_id,
                "inviterUserId": inviter_user_id,
                "email": email,
                "role": role,
                "token": token,
                "expiresAt": expires_at,
                "acceptedAt": accepted_at,
                "createdAt": created_at,
                "updatedAt": updated_at,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        id = d.pop("id")

        team_id = d.pop("teamId")

        tenant_id = d.pop("tenantId")

        def _parse_inviter_user_id(data: object) -> float | None:
            if data is None:
                return data
            return cast(float | None, data)

        inviter_user_id = _parse_inviter_user_id(d.pop("inviterUserId"))

        email = d.pop("email")

        role = Schema69(d.pop("role"))

        token = d.pop("token")

        expires_at = d.pop("expiresAt")

        def _parse_accepted_at(data: object) -> None | str:
            if data is None:
                return data
            return cast(None | str, data)

        accepted_at = _parse_accepted_at(d.pop("acceptedAt"))

        created_at = d.pop("createdAt")

        updated_at = d.pop("updatedAt")

        team_invitation = cls(
            id=id,
            team_id=team_id,
            tenant_id=tenant_id,
            inviter_user_id=inviter_user_id,
            email=email,
            role=role,
            token=token,
            expires_at=expires_at,
            accepted_at=accepted_at,
            created_at=created_at,
            updated_at=updated_at,
        )

        return team_invitation



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast






T = TypeVar("T", bound="AuditLogResponse")



@_attrs_define
class AuditLogResponse:
    """ 
        Attributes:
            id (float):
            tenant_id (str):
            event_time (str):
            entity_type (None | str):
            entity_id (None | str):
            event_name (str):
            user_id (float | None):
            details (Any):
            only_superadmin_visibility (bool):
            created_at (str):
            user_full_name (str):
            user_email (None | str):
            user_sub (None | str):
            team_name (None | str):
            server_slug (None | str):
     """

    id: float
    tenant_id: str
    event_time: str
    entity_type: None | str
    entity_id: None | str
    event_name: str
    user_id: float | None
    details: Any
    only_superadmin_visibility: bool
    created_at: str
    user_full_name: str
    user_email: None | str
    user_sub: None | str
    team_name: None | str
    server_slug: None | str





    def to_dict(self) -> dict[str, Any]:
        id = self.id

        tenant_id = self.tenant_id

        event_time = self.event_time

        entity_type: None | str
        entity_type = self.entity_type

        entity_id: None | str
        entity_id = self.entity_id

        event_name = self.event_name

        user_id: float | None
        user_id = self.user_id

        details = self.details

        only_superadmin_visibility = self.only_superadmin_visibility

        created_at = self.created_at

        user_full_name = self.user_full_name

        user_email: None | str
        user_email = self.user_email

        user_sub: None | str
        user_sub = self.user_sub

        team_name: None | str
        team_name = self.team_name

        server_slug: None | str
        server_slug = self.server_slug


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "id": id,
            "tenantId": tenant_id,
            "eventTime": event_time,
            "entityType": entity_type,
            "entityId": entity_id,
            "eventName": event_name,
            "userId": user_id,
            "details": details,
            "onlySuperadminVisibility": only_superadmin_visibility,
            "createdAt": created_at,
            "userFullName": user_full_name,
            "userEmail": user_email,
            "userSub": user_sub,
            "teamName": team_name,
            "serverSlug": server_slug,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        id = d.pop("id")

        tenant_id = d.pop("tenantId")

        event_time = d.pop("eventTime")

        def _parse_entity_type(data: object) -> None | str:
            if data is None:
                return data
            return cast(None | str, data)

        entity_type = _parse_entity_type(d.pop("entityType"))


        def _parse_entity_id(data: object) -> None | str:
            if data is None:
                return data
            return cast(None | str, data)

        entity_id = _parse_entity_id(d.pop("entityId"))


        event_name = d.pop("eventName")

        def _parse_user_id(data: object) -> float | None:
            if data is None:
                return data
            return cast(float | None, data)

        user_id = _parse_user_id(d.pop("userId"))


        details = d.pop("details")

        only_superadmin_visibility = d.pop("onlySuperadminVisibility")

        created_at = d.pop("createdAt")

        user_full_name = d.pop("userFullName")

        def _parse_user_email(data: object) -> None | str:
            if data is None:
                return data
            return cast(None | str, data)

        user_email = _parse_user_email(d.pop("userEmail"))


        def _parse_user_sub(data: object) -> None | str:
            if data is None:
                return data
            return cast(None | str, data)

        user_sub = _parse_user_sub(d.pop("userSub"))


        def _parse_team_name(data: object) -> None | str:
            if data is None:
                return data
            return cast(None | str, data)

        team_name = _parse_team_name(d.pop("teamName"))


        def _parse_server_slug(data: object) -> None | str:
            if data is None:
                return data
            return cast(None | str, data)

        server_slug = _parse_server_slug(d.pop("serverSlug"))


        audit_log_response = cls(
            id=id,
            tenant_id=tenant_id,
            event_time=event_time,
            entity_type=entity_type,
            entity_id=entity_id,
            event_name=event_name,
            user_id=user_id,
            details=details,
            only_superadmin_visibility=only_superadmin_visibility,
            created_at=created_at,
            user_full_name=user_full_name,
            user_email=user_email,
            user_sub=user_sub,
            team_name=team_name,
            server_slug=server_slug,
        )

        return audit_log_response




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.schema_17 import Schema17
from ..types import UNSET, Unset
from typing import cast
from typing import Literal, cast






T = TypeVar("T", bound="PutMcpServersServerSlugConfigBodyType2")



@_attrs_define
class PutMcpServersServerSlugConfigBodyType2:
    """ 
        Attributes:
            type_ (Literal['stdio'] | Unset):
            command (str | Unset):
            docker_image (str | Unset):
            env (list[list[str]] | Unset):
            transport (Schema17 | Unset):
            http_port (float | None | Unset):
            url_path (None | str | Unset):
     """

    type_: Literal['stdio'] | Unset = UNSET
    command: str | Unset = UNSET
    docker_image: str | Unset = UNSET
    env: list[list[str]] | Unset = UNSET
    transport: Schema17 | Unset = UNSET
    http_port: float | None | Unset = UNSET
    url_path: None | str | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        type_ = self.type_

        command = self.command

        docker_image = self.docker_image

        env: list[list[str]] | Unset = UNSET
        if not isinstance(self.env, Unset):
            env = []
            for componentsschemas_schema16_item_data in self.env:
                componentsschemas_schema16_item = []
                for componentsschemas_schema16_item_item_data in componentsschemas_schema16_item_data:
                    componentsschemas_schema16_item_item: str
                    componentsschemas_schema16_item_item = componentsschemas_schema16_item_item_data
                    componentsschemas_schema16_item.append(componentsschemas_schema16_item_item)


                env.append(componentsschemas_schema16_item)



        transport: str | Unset = UNSET
        if not isinstance(self.transport, Unset):
            transport = self.transport.value


        http_port: float | None | Unset
        if isinstance(self.http_port, Unset):
            http_port = UNSET
        else:
            http_port = self.http_port

        url_path: None | str | Unset
        if isinstance(self.url_path, Unset):
            url_path = UNSET
        else:
            url_path = self.url_path


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if type_ is not UNSET:
            field_dict["type"] = type_
        if command is not UNSET:
            field_dict["command"] = command
        if docker_image is not UNSET:
            field_dict["dockerImage"] = docker_image
        if env is not UNSET:
            field_dict["env"] = env
        if transport is not UNSET:
            field_dict["transport"] = transport
        if http_port is not UNSET:
            field_dict["httpPort"] = http_port
        if url_path is not UNSET:
            field_dict["urlPath"] = url_path

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        type_ = cast(Literal['stdio'] | Unset , d.pop("type", UNSET))
        if type_ != 'stdio'and not isinstance(type_, Unset):
            raise ValueError(f"type must match const 'stdio', got '{type_}'")

        command = d.pop("command", UNSET)

        docker_image = d.pop("dockerImage", UNSET)

        _env = d.pop("env", UNSET)
        env: list[list[str]] | Unset = UNSET
        if _env is not UNSET:
            env = []
            for componentsschemas_schema16_item_data in _env:
                componentsschemas_schema16_item = []
                _componentsschemas_schema16_item = componentsschemas_schema16_item_data
                for componentsschemas_schema16_item_item_data in (_componentsschemas_schema16_item):
                    def _parse_componentsschemas_schema16_item_item(data: object) -> str:
                        return cast(str, data)

                    componentsschemas_schema16_item_item = _parse_componentsschemas_schema16_item_item(componentsschemas_schema16_item_item_data)

                    componentsschemas_schema16_item.append(componentsschemas_schema16_item_item)

                env.append(componentsschemas_schema16_item)


        _transport = d.pop("transport", UNSET)
        transport: Schema17 | Unset
        if isinstance(_transport,  Unset):
            transport = UNSET
        else:
            transport = Schema17(_transport)




        def _parse_http_port(data: object) -> float | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(float | None | Unset, data)

        http_port = _parse_http_port(d.pop("httpPort", UNSET))


        def _parse_url_path(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        url_path = _parse_url_path(d.pop("urlPath", UNSET))


        put_mcp_servers_server_slug_config_body_type_2 = cls(
            type_=type_,
            command=command,
            docker_image=docker_image,
            env=env,
            transport=transport,
            http_port=http_port,
            url_path=url_path,
        )


        put_mcp_servers_server_slug_config_body_type_2.additional_properties = d
        return put_mcp_servers_server_slug_config_body_type_2

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset






T = TypeVar("T", bound="ServerPodStatus")



@_attrs_define
class ServerPodStatus:
    """ 
        Attributes:
            name (str):
            ready (bool):
            phase (str | Unset):
            reason (str | Unset):
            created_at (str | Unset):
     """

    name: str
    ready: bool
    phase: str | Unset = UNSET
    reason: str | Unset = UNSET
    created_at: str | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        name = self.name

        ready = self.ready

        phase = self.phase

        reason = self.reason

        created_at = self.created_at


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "name": name,
            "ready": ready,
        })
        if phase is not UNSET:
            field_dict["phase"] = phase
        if reason is not UNSET:
            field_dict["reason"] = reason
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        name = d.pop("name")

        ready = d.pop("ready")

        phase = d.pop("phase", UNSET)

        reason = d.pop("reason", UNSET)

        created_at = d.pop("createdAt", UNSET)

        server_pod_status = cls(
            name=name,
            ready=ready,
            phase=phase,
            reason=reason,
            created_at=created_at,
        )

        return server_pod_status

